@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Maximum Entropy Classifiers
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2019 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 #         Dmitry Chichkov <dchichkov@gmail.com> (TypedMaxentFeatureEncoding)
 # URL: <http://nltk.org/>
@@ -60,7 +60,6 @@ except ImportError:
 
 import tempfile
 import os
-import re
 from collections import defaultdict
 
 from six import integer_types
@@ -72,16 +71,16 @@ from nltk.probability import DictionaryProbDist
 
 from nltk.classify.api import ClassifierI
 from nltk.classify.util import CutoffChecker, accuracy, log_likelihood
-from nltk.classify.megam import (call_megam,
-                                 write_megam_file, parse_megam_weights)
+from nltk.classify.megam import call_megam, write_megam_file, parse_megam_weights
 from nltk.classify.tadm import call_tadm, write_tadm_file, parse_tadm_weights
 
 __docformat__ = 'epytext en'
 
 ######################################################################
-#{ Classifier Model
+# { Classifier Model
 ######################################################################
 
+
 @compat.python_2_unicode_compatible
 class MaxentClassifier(ClassifierI):
     """
@@ -101,6 +100,7 @@ class MaxentClassifier(ClassifierI):
 
       dotprod(a,b) = sum(x*y for (x,y) in zip(a,b))
     """
+
     def __init__(self, encoding, weights, logarithmic=True):
         """
         Construct a new maxent classifier model.  Typically, new
@@ -121,7 +121,7 @@ class MaxentClassifier(ClassifierI):
         self._encoding = encoding
         self._weights = weights
         self._logarithmic = logarithmic
-        #self._logarithmic = False
+        # self._logarithmic = False
         assert encoding.length() == len(weights)
 
     def labels(self):
@@ -164,8 +164,7 @@ class MaxentClassifier(ClassifierI):
                 prob_dict[label] = prod
 
         # Normalize the dictionary to give a probability distribution
-        return DictionaryProbDist(prob_dict, log=self._logarithmic,
-                                  normalize=True)
+        return DictionaryProbDist(prob_dict, log=self._logarithmic, normalize=True)
 
     def explain(self, featureset, columns=4):
         """
@@ -174,35 +173,42 @@ class MaxentClassifier(ClassifierI):
         probabilities of each label for that featureset.
         """
         descr_width = 50
-        TEMPLATE = '  %-'+str(descr_width-2)+'s%s%8.3f'
+        TEMPLATE = '  %-' + str(descr_width - 2) + 's%s%8.3f'
 
         pdist = self.prob_classify(featureset)
         labels = sorted(pdist.samples(), key=pdist.prob, reverse=True)
         labels = labels[:columns]
-        print('  Feature'.ljust(descr_width)+''.join(
-            '%8s' % (("%s" % l)[:7]) for l in labels))
-        print('  '+'-'*(descr_width-2+8*len(labels)))
+        print(
+            '  Feature'.ljust(descr_width)
+            + ''.join('%8s' % (("%s" % l)[:7]) for l in labels)
+        )
+        print('  ' + '-' * (descr_width - 2 + 8 * len(labels)))
         sums = defaultdict(int)
         for i, label in enumerate(labels):
             feature_vector = self._encoding.encode(featureset, label)
-            feature_vector.sort(key=lambda fid__: abs(self._weights[fid__[0]]),
-                                reverse=True)
+            feature_vector.sort(
+                key=lambda fid__: abs(self._weights[fid__[0]]), reverse=True
+            )
             for (f_id, f_val) in feature_vector:
                 if self._logarithmic:
                     score = self._weights[f_id] * f_val
-                else: score = self._weights[f_id] ** f_val
+                else:
+                    score = self._weights[f_id] ** f_val
                 descr = self._encoding.describe(f_id)
-                descr = descr.split(' and label is ')[0] # hack
-                descr += ' (%s)' % f_val                 # hack
+                descr = descr.split(' and label is ')[0]  # hack
+                descr += ' (%s)' % f_val  # hack
                 if len(descr) > 47:
-                    descr = descr[:44]+'...'
-                print(TEMPLATE % (descr, i*8*' ', score))
+                    descr = descr[:44] + '...'
+                print(TEMPLATE % (descr, i * 8 * ' ', score))
                 sums[label] += score
-        print('  '+'-'*(descr_width-1+8*len(labels)))
-        print('  TOTAL:'.ljust(descr_width)+''.join(
-            '%8.3f' % sums[l] for l in labels))
-        print('  PROBS:'.ljust(descr_width)+''.join(
-            '%8.3f' % pdist.prob(l) for l in labels))
+        print('  ' + '-' * (descr_width - 1 + 8 * len(labels)))
+        print(
+            '  TOTAL:'.ljust(descr_width) + ''.join('%8.3f' % sums[l] for l in labels)
+        )
+        print(
+            '  PROBS:'.ljust(descr_width)
+            + ''.join('%8.3f' % pdist.prob(l) for l in labels)
+        )
 
     def most_informative_features(self, n=10):
         """
@@ -211,9 +217,11 @@ class MaxentClassifier(ClassifierI):
         if hasattr(self, '_most_informative_features'):
             return self._most_informative_features[:n]
         else:
-            self._most_informative_features = sorted(list(range(len(self._weights))),
-                                                key=lambda fid: abs(self._weights[fid]),
-                                                reverse=True)
+            self._most_informative_features = sorted(
+                list(range(len(self._weights))),
+                key=lambda fid: abs(self._weights[fid]),
+                reverse=True,
+            )
             return self._most_informative_features[:n]
 
     def show_most_informative_features(self, n=10, show='all'):
@@ -230,20 +238,29 @@ class MaxentClassifier(ClassifierI):
         elif show == 'neg':
             fids = [fid for fid in fids if self._weights[fid] < 0]
         for fid in fids[:n]:
-            print('%8.3f %s' % (self._weights[fid],
-                                self._encoding.describe(fid)))
+            print('%8.3f %s' % (self._weights[fid], self._encoding.describe(fid)))
 
     def __repr__(self):
-        return ('<ConditionalExponentialClassifier: %d labels, %d features>' %
-                (len(self._encoding.labels()), self._encoding.length()))
+        return '<ConditionalExponentialClassifier: %d labels, %d features>' % (
+            len(self._encoding.labels()),
+            self._encoding.length(),
+        )
 
     #: A list of the algorithm names that are accepted for the
     #: ``train()`` method's ``algorithm`` parameter.
     ALGORITHMS = ['GIS', 'IIS', 'MEGAM', 'TADM']
 
     @classmethod
-    def train(cls, train_toks, algorithm=None, trace=3, encoding=None,
-              labels=None, gaussian_prior_sigma=0, **cutoffs):
+    def train(
+        cls,
+        train_toks,
+        algorithm=None,
+        trace=3,
+        encoding=None,
+        labels=None,
+        gaussian_prior_sigma=0,
+        **cutoffs
+    ):
         """
         Train a new maxent classifier based on the given corpus of
         training samples.  This classifier will have its weights
@@ -298,21 +315,31 @@ class MaxentClassifier(ClassifierI):
         if algorithm is None:
             algorithm = 'iis'
         for key in cutoffs:
-            if key not in ('max_iter', 'min_ll', 'min_lldelta',
-                           'max_acc', 'min_accdelta', 'count_cutoff',
-                           'norm', 'explicit', 'bernoulli'):
+            if key not in (
+                'max_iter',
+                'min_ll',
+                'min_lldelta',
+                'max_acc',
+                'min_accdelta',
+                'count_cutoff',
+                'norm',
+                'explicit',
+                'bernoulli',
+            ):
                 raise TypeError('Unexpected keyword arg %r' % key)
         algorithm = algorithm.lower()
         if algorithm == 'iis':
             return train_maxent_classifier_with_iis(
-                train_toks, trace, encoding, labels, **cutoffs)
+                train_toks, trace, encoding, labels, **cutoffs
+            )
         elif algorithm == 'gis':
             return train_maxent_classifier_with_gis(
-                train_toks, trace, encoding, labels, **cutoffs)
+                train_toks, trace, encoding, labels, **cutoffs
+            )
         elif algorithm == 'megam':
             return train_maxent_classifier_with_megam(
-                train_toks, trace, encoding, labels,
-                gaussian_prior_sigma, **cutoffs)
+                train_toks, trace, encoding, labels, gaussian_prior_sigma, **cutoffs
+            )
         elif algorithm == 'tadm':
             kwargs = cutoffs
             kwargs['trace'] = trace
@@ -329,9 +356,10 @@ ConditionalExponentialClassifier = MaxentClassifier
 
 
 ######################################################################
-#{ Feature Encodings
+# { Feature Encodings
 ######################################################################
 
+
 class MaxentFeatureEncodingI(object):
     """
     A mapping that converts a set of input-feature values to a vector
@@ -354,6 +382,7 @@ class MaxentFeatureEncodingI(object):
     input-feature values and labels that are present in a given
     corpus.
     """
+
     def encode(self, featureset, label):
         """
         Given a (featureset, label) pair, return the corresponding
@@ -403,11 +432,13 @@ class MaxentFeatureEncodingI(object):
         """
         raise NotImplementedError()
 
+
 class FunctionBackedMaxentFeatureEncoding(MaxentFeatureEncodingI):
     """
     A feature encoding that calls a user-supplied function to map a
     given featureset/label pair to a sparse joint-feature vector.
     """
+
     def __init__(self, func, length, labels):
         """
         Construct a new feature encoding based on the given function.
@@ -448,6 +479,7 @@ class FunctionBackedMaxentFeatureEncoding(MaxentFeatureEncodingI):
     def describe(self, fid):
         return 'no description available'
 
+
 class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
     """
     A feature encoding that generates vectors containing a binary
@@ -488,8 +520,8 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
     These always-on features allow the maxent model to directly model
     the prior probabilities of each label.
     """
-    def __init__(self, labels, mapping, unseen_features=False,
-                 alwayson_features=False):
+
+    def __init__(self, labels, mapping, unseen_features=False, alwayson_features=False):
         """
         :param labels: A list of the \"known labels\" for this encoding.
 
@@ -507,8 +539,10 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
            features in the generated joint-feature vectors.
         """
         if set(mapping.values()) != set(range(len(mapping))):
-            raise ValueError('Mapping values must be exactly the '
-                             'set of integers from 0...len(mapping)')
+            raise ValueError(
+                'Mapping values must be exactly the '
+                'set of integers from 0...len(mapping)'
+            )
 
         self._labels = list(labels)
         """A list of attested labels."""
@@ -526,14 +560,16 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
         """dict mapping from fname -> fid"""
 
         if alwayson_features:
-            self._alwayson = dict((label, i+self._length)
-                                  for (i, label) in enumerate(labels))
+            self._alwayson = dict(
+                (label, i + self._length) for (i, label) in enumerate(labels)
+            )
             self._length += len(self._alwayson)
 
         if unseen_features:
             fnames = set(fname for (fname, fval, label) in mapping)
-            self._unseen = dict((fname, i+self._length)
-                                for (i, fname) in enumerate(fnames))
+            self._unseen = dict(
+                (fname, i + self._length) for (i, fname) in enumerate(fnames)
+            )
             self._length += len(fnames)
 
     def encode(self, featureset, label):
@@ -551,7 +587,7 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
                 # Have we seen this fname/fval combination with any label?
                 for label2 in self._labels:
                     if (fname, fval, label2) in self._mapping:
-                        break # we've seen this fname/fval combo
+                        break  # we've seen this fname/fval combo
                 # We haven't -- fire the unseen-value feature
                 else:
                     if fname in self._unseen:
@@ -570,7 +606,7 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
         try:
             self._inv_mapping
         except AttributeError:
-            self._inv_mapping = [-1]*len(self._mapping)
+            self._inv_mapping = [-1] * len(self._mapping)
             for (info, i) in self._mapping.items():
                 self._inv_mapping[i] = info
 
@@ -624,8 +660,8 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
         :param options: Extra parameters for the constructor, such as
             ``unseen_features`` and ``alwayson_features``.
         """
-        mapping = {}              # maps (fname, fval, label) -> fid
-        seen_labels = set()       # The set of labels we've encountered
+        mapping = {}  # maps (fname, fval, label) -> fid
+        seen_labels = set()  # The set of labels we've encountered
         count = defaultdict(int)  # maps (fname, fval) -> count
 
         for (tok, label) in train_toks:
@@ -648,6 +684,7 @@ class BinaryMaxentFeatureEncoding(MaxentFeatureEncodingI):
             labels = seen_labels
         return cls(labels, mapping, **options)
 
+
 class GISEncoding(BinaryMaxentFeatureEncoding):
     """
     A binary feature encoding which adds one new joint-feature to the
@@ -662,8 +699,10 @@ class GISEncoding(BinaryMaxentFeatureEncoding):
       - The feature vector must sum to a constant non-negative number
         for every token.
     """
-    def __init__(self, labels, mapping, unseen_features=False,
-                 alwayson_features=False, C=None):
+
+    def __init__(
+        self, labels, mapping, unseen_features=False, alwayson_features=False, C=None
+    ):
         """
         :param C: The correction constant.  The value of the correction
             feature is based on this value.  In particular, its value is
@@ -671,9 +710,10 @@ class GISEncoding(BinaryMaxentFeatureEncoding):
         :seealso: ``BinaryMaxentFeatureEncoding.__init__``
         """
         BinaryMaxentFeatureEncoding.__init__(
-            self, labels, mapping, unseen_features, alwayson_features)
+            self, labels, mapping, unseen_features, alwayson_features
+        )
         if C is None:
-            C = len(set(fname for (fname, fval, label) in mapping))+1
+            C = len(set(fname for (fname, fval, label) in mapping)) + 1
         self._C = C
 
     @property
@@ -691,7 +731,7 @@ class GISEncoding(BinaryMaxentFeatureEncoding):
         total = sum(v for (f, v) in encoding)
         if total >= self._C:
             raise ValueError('Correction feature is not high enough!')
-        encoding.append((base_length, self._C-total))
+        encoding.append((base_length, self._C - total))
 
         # Return the result
         return encoding
@@ -707,13 +747,12 @@ class GISEncoding(BinaryMaxentFeatureEncoding):
 
 
 class TadmEventMaxentFeatureEncoding(BinaryMaxentFeatureEncoding):
-    def __init__(self, labels, mapping, unseen_features=False,
-                       alwayson_features=False):
+    def __init__(self, labels, mapping, unseen_features=False, alwayson_features=False):
         self._mapping = OrderedDict(mapping)
         self._label_mapping = OrderedDict()
-        BinaryMaxentFeatureEncoding.__init__(self, labels, self._mapping,
-                                             unseen_features,
-                                             alwayson_features)
+        BinaryMaxentFeatureEncoding.__init__(
+            self, labels, self._mapping, unseen_features, alwayson_features
+        )
 
     def encode(self, featureset, label):
         encoding = []
@@ -725,8 +764,9 @@ class TadmEventMaxentFeatureEncoding(BinaryMaxentFeatureEncoding):
                     self._label_mapping[value] = len(self._label_mapping)
                 else:
                     self._label_mapping[value] = value
-            encoding.append((self._mapping[(feature, label)],
-                             self._label_mapping[value]))
+            encoding.append(
+                (self._mapping[(feature, label)], self._label_mapping[value])
+            )
         return encoding
 
     def labels(self):
@@ -818,8 +858,8 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
     These always-on features allow the maxent model to directly model
     the prior probabilities of each label.
     """
-    def __init__(self, labels, mapping, unseen_features=False,
-                 alwayson_features=False):
+
+    def __init__(self, labels, mapping, unseen_features=False, alwayson_features=False):
         """
         :param labels: A list of the \"known labels\" for this encoding.
 
@@ -837,8 +877,10 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
            features in the generated joint-feature vectors.
         """
         if set(mapping.values()) != set(range(len(mapping))):
-            raise ValueError('Mapping values must be exactly the '
-                             'set of integers from 0...len(mapping)')
+            raise ValueError(
+                'Mapping values must be exactly the '
+                'set of integers from 0...len(mapping)'
+            )
 
         self._labels = list(labels)
         """A list of attested labels."""
@@ -856,14 +898,16 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
         """dict mapping from fname -> fid"""
 
         if alwayson_features:
-            self._alwayson = dict((label, i+self._length)
-                                  for (i, label) in enumerate(labels))
+            self._alwayson = dict(
+                (label, i + self._length) for (i, label) in enumerate(labels)
+            )
             self._length += len(self._alwayson)
 
         if unseen_features:
             fnames = set(fname for (fname, fval, label) in mapping)
-            self._unseen = dict((fname, i+self._length)
-                                for (i, fname) in enumerate(fnames))
+            self._unseen = dict(
+                (fname, i + self._length) for (i, fname) in enumerate(fnames)
+            )
             self._length += len(fnames)
 
     def encode(self, featureset, label):
@@ -875,8 +919,7 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
             if isinstance(fval, (integer_types, float)):
                 # Known feature name & value:
                 if (fname, type(fval), label) in self._mapping:
-                    encoding.append((self._mapping[fname, type(fval),
-                                                   label], fval))
+                    encoding.append((self._mapping[fname, type(fval), label], fval))
             else:
                 # Known feature name & value:
                 if (fname, fval, label) in self._mapping:
@@ -887,13 +930,12 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
                     # Have we seen this fname/fval combination with any label?
                     for label2 in self._labels:
                         if (fname, fval, label2) in self._mapping:
-                            break # we've seen this fname/fval combo
+                            break  # we've seen this fname/fval combo
                     # We haven't -- fire the unseen-value feature
                     else:
                         if fname in self._unseen:
                             encoding.append((self._unseen[fname], 1))
 
-
         # Add always-on features:
         if self._alwayson and label in self._alwayson:
             encoding.append((self._alwayson[label], 1))
@@ -907,7 +949,7 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
         try:
             self._inv_mapping
         except AttributeError:
-            self._inv_mapping = [-1]*len(self._mapping)
+            self._inv_mapping = [-1] * len(self._mapping)
             for (info, i) in self._mapping.items():
                 self._inv_mapping[i] = info
 
@@ -964,8 +1006,8 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
         :param options: Extra parameters for the constructor, such as
             ``unseen_features`` and ``alwayson_features``.
         """
-        mapping = {}              # maps (fname, fval, label) -> fid
-        seen_labels = set()       # The set of labels we've encountered
+        mapping = {}  # maps (fname, fval, label) -> fid
+        seen_labels = set()  # The set of labels we've encountered
         count = defaultdict(int)  # maps (fname, fval) -> count
 
         for (tok, label) in train_toks:
@@ -990,14 +1032,14 @@ class TypedMaxentFeatureEncoding(MaxentFeatureEncodingI):
         return cls(labels, mapping, **options)
 
 
-
-
 ######################################################################
-#{ Classifier Trainer: Generalized Iterative Scaling
+# { Classifier Trainer: Generalized Iterative Scaling
 ######################################################################
 
-def train_maxent_classifier_with_gis(train_toks, trace=3, encoding=None,
-                                     labels=None, **cutoffs):
+
+def train_maxent_classifier_with_gis(
+    train_toks, trace=3, encoding=None, labels=None, **cutoffs
+):
     """
     Train a new ``ConditionalExponentialClassifier``, using the given
     training samples, using the Generalized Iterative Scaling
@@ -1015,13 +1057,15 @@ def train_maxent_classifier_with_gis(train_toks, trace=3, encoding=None,
         encoding = GISEncoding.train(train_toks, labels=labels)
 
     if not hasattr(encoding, 'C'):
-        raise TypeError('The GIS algorithm requires an encoding that '
-                        'defines C (e.g., GISEncoding).')
+        raise TypeError(
+            'The GIS algorithm requires an encoding that '
+            'defines C (e.g., GISEncoding).'
+        )
 
     # Cinv is the inverse of the sum of each joint feature vector.
     # This controls the learning rate: higher Cinv (or lower C) gives
     # faster learning.
-    Cinv = 1.0/encoding.C
+    Cinv = 1.0 / encoding.C
 
     # Count how many times each feature occurs in the training data.
     empirical_fcount = calculate_empirical_fcount(train_toks, encoding)
@@ -1059,7 +1103,8 @@ def train_maxent_classifier_with_gis(train_toks, trace=3, encoding=None,
             # Use the model to estimate the number of times each
             # feature should occur in the training data.
             estimated_fcount = calculate_estimated_fcount(
-                classifier, train_toks, encoding)
+                classifier, train_toks, encoding
+            )
 
             # Take the log of estimated fcount (avoid taking log(0).)
             for fid in unattested:
@@ -1086,9 +1131,10 @@ def train_maxent_classifier_with_gis(train_toks, trace=3, encoding=None,
         acc = accuracy(classifier, train_toks)
         print('         Final    %14.5f    %9.3f' % (ll, acc))
 
-# Return the classifier.
+    # Return the classifier.
     return classifier
 
+
 def calculate_empirical_fcount(train_toks, encoding):
     fcount = numpy.zeros(encoding.length(), 'd')
 
@@ -1098,6 +1144,7 @@ def calculate_empirical_fcount(train_toks, encoding):
 
     return fcount
 
+
 def calculate_estimated_fcount(classifier, train_toks, encoding):
     fcount = numpy.zeros(encoding.length(), 'd')
 
@@ -1106,17 +1153,19 @@ def calculate_estimated_fcount(classifier, train_toks, encoding):
         for label in pdist.samples():
             prob = pdist.prob(label)
             for (fid, fval) in encoding.encode(tok, label):
-                fcount[fid] += prob*fval
+                fcount[fid] += prob * fval
 
     return fcount
 
 
 ######################################################################
-#{ Classifier Trainer: Improved Iterative Scaling
+# { Classifier Trainer: Improved Iterative Scaling
 ######################################################################
 
-def train_maxent_classifier_with_iis(train_toks, trace=3, encoding=None,
-                                     labels=None, **cutoffs):
+
+def train_maxent_classifier_with_iis(
+    train_toks, trace=3, encoding=None, labels=None, **cutoffs
+):
     """
     Train a new ``ConditionalExponentialClassifier``, using the given
     training samples, using the Improved Iterative Scaling algorithm.
@@ -1134,8 +1183,7 @@ def train_maxent_classifier_with_iis(train_toks, trace=3, encoding=None,
         encoding = BinaryMaxentFeatureEncoding.train(train_toks, labels=labels)
 
     # Count how many times each feature occurs in the training data.
-    empirical_ffreq = (calculate_empirical_fcount(train_toks, encoding) /
-                       len(train_toks))
+    empirical_ffreq = calculate_empirical_fcount(train_toks, encoding) / len(train_toks)
 
     # Find the nf map, and related variables nfarray and nfident.
     # nf is the sum of the features for a given labeled text.
@@ -1174,8 +1222,15 @@ def train_maxent_classifier_with_iis(train_toks, trace=3, encoding=None,
 
             # Calculate the deltas for this iteration, using Newton's method.
             deltas = calculate_deltas(
-                train_toks, classifier, unattested, empirical_ffreq,
-                nfmap, nfarray, nftranspose, encoding)
+                train_toks,
+                classifier,
+                unattested,
+                empirical_ffreq,
+                nfmap,
+                nfarray,
+                nftranspose,
+                encoding,
+            )
 
             # Use the deltas to update our weights.
             weights = classifier.weights()
@@ -1191,7 +1246,6 @@ def train_maxent_classifier_with_iis(train_toks, trace=3, encoding=None,
     except:
         raise
 
-
     if trace > 2:
         ll = log_likelihood(classifier, train_toks)
         acc = accuracy(classifier, train_toks)
@@ -1200,6 +1254,7 @@ def train_maxent_classifier_with_iis(train_toks, trace=3, encoding=None,
     # Return the classifier.
     return classifier
 
+
 def calculate_nfmap(train_toks, encoding):
     """
     Construct a map that can be used to compress ``nf`` (which is
@@ -1227,8 +1282,17 @@ def calculate_nfmap(train_toks, encoding):
             nfset.add(sum(val for (id, val) in encoding.encode(tok, label)))
     return dict((nf, i) for (i, nf) in enumerate(nfset))
 
-def calculate_deltas(train_toks, classifier, unattested, ffreq_empirical,
-                     nfmap, nfarray, nftranspose, encoding):
+
+def calculate_deltas(
+    train_toks,
+    classifier,
+    unattested,
+    ffreq_empirical,
+    nfmap,
+    nfarray,
+    nftranspose,
+    encoding,
+):
     """
     Calculate the update values for the classifier weights for
     this iteration of IIS.  These update weights are the value of
@@ -1338,24 +1402,24 @@ def calculate_deltas(train_toks, classifier, unattested, ffreq_empirical,
         deltas -= (ffreq_empirical - sum1) / -sum2
 
         # We can stop once we converge.
-        n_error = (numpy.sum(abs((ffreq_empirical-sum1)))/
-                   numpy.sum(abs(deltas)))
+        n_error = numpy.sum(abs((ffreq_empirical - sum1))) / numpy.sum(abs(deltas))
         if n_error < NEWTON_CONVERGE:
             return deltas
 
     return deltas
 
+
 ######################################################################
-#{ Classifier Trainer: megam
+# { Classifier Trainer: megam
 ######################################################################
 
 # [xx] possible extension: add support for using implicit file format;
 # this would need to put requirements on what encoding is used.  But
 # we may need this for other maxent classifier trainers that require
 # implicit formats anyway.
-def train_maxent_classifier_with_megam(train_toks, trace=3, encoding=None,
-                                       labels=None, gaussian_prior_sigma=0,
-                                       **kwargs):
+def train_maxent_classifier_with_megam(
+    train_toks, trace=3, encoding=None, labels=None, gaussian_prior_sigma=0, **kwargs
+):
     """
     Train a new ``ConditionalExponentialClassifier``, using the given
     training samples, using the external ``megam`` library.  This
@@ -1379,9 +1443,9 @@ def train_maxent_classifier_with_megam(train_toks, trace=3, encoding=None,
         # Count cutoff can also be controlled by megam with the -minfc
         # option. Not sure where the best place for it is.
         count_cutoff = kwargs.get('count_cutoff', 0)
-        encoding = BinaryMaxentFeatureEncoding.train(train_toks, count_cutoff,
-                                                     labels=labels,
-                                                     alwayson_features=True)
+        encoding = BinaryMaxentFeatureEncoding.train(
+            train_toks, count_cutoff, labels=labels, alwayson_features=True
+        )
     elif labels is not None:
         raise ValueError('Specify encoding or labels, not both')
 
@@ -1389,8 +1453,9 @@ def train_maxent_classifier_with_megam(train_toks, trace=3, encoding=None,
     try:
         fd, trainfile_name = tempfile.mkstemp(prefix='nltk-')
         with open(trainfile_name, 'w') as trainfile:
-            write_megam_file(train_toks, encoding, trainfile,
-                             explicit=explicit, bernoulli=bernoulli)
+            write_megam_file(
+                train_toks, encoding, trainfile, explicit=explicit, bernoulli=bernoulli
+            )
         os.close(fd)
     except (OSError, IOError, ValueError) as e:
         raise ValueError('Error while creating megam training file: %s' % e)
@@ -1406,7 +1471,7 @@ def train_maxent_classifier_with_megam(train_toks, trace=3, encoding=None,
         # Lambda is just the precision of the Gaussian prior, i.e. it's the
         # inverse variance, so the parameter conversion is 1.0/sigma**2.
         # See http://www.umiacs.umd.edu/~hal/docs/daume04cg-bfgs.pdf.
-        inv_variance = 1.0 / gaussian_prior_sigma**2
+        inv_variance = 1.0 / gaussian_prior_sigma ** 2
     else:
         inv_variance = 0
     options += ['-lambda', '%.2f' % inv_variance, '-tune']
@@ -1438,10 +1503,12 @@ def train_maxent_classifier_with_megam(train_toks, trace=3, encoding=None,
     # Build the classifier
     return MaxentClassifier(encoding, weights)
 
+
 ######################################################################
-#{ Classifier Trainer: tadm
+# { Classifier Trainer: tadm
 ######################################################################
 
+
 class TadmMaxentClassifier(MaxentClassifier):
     @classmethod
     def train(cls, train_toks, **kwargs):
@@ -1456,14 +1523,14 @@ class TadmMaxentClassifier(MaxentClassifier):
 
         # Construct an encoding from the training data.
         if not encoding:
-            encoding = TadmEventMaxentFeatureEncoding.train(train_toks,
-                                                            count_cutoff,
-                                                            labels=labels)
+            encoding = TadmEventMaxentFeatureEncoding.train(
+                train_toks, count_cutoff, labels=labels
+            )
 
-        trainfile_fd, trainfile_name = \
-            tempfile.mkstemp(prefix='nltk-tadm-events-', suffix='.gz')
-        weightfile_fd, weightfile_name = \
-            tempfile.mkstemp(prefix='nltk-tadm-weights-')
+        trainfile_fd, trainfile_name = tempfile.mkstemp(
+            prefix='nltk-tadm-events-', suffix='.gz'
+        )
+        weightfile_fd, weightfile_name = tempfile.mkstemp(prefix='nltk-tadm-weights-')
 
         trainfile = gzip_open_unicode(trainfile_name, 'w')
         write_tadm_file(train_toks, encoding, trainfile)
@@ -1473,7 +1540,7 @@ class TadmMaxentClassifier(MaxentClassifier):
         options.extend(['-monitor'])
         options.extend(['-method', algorithm])
         if sigma:
-            options.extend(['-l2', '%.6f' % sigma**2])
+            options.extend(['-l2', '%.6f' % sigma ** 2])
         if max_iter:
             options.extend(['-max_it', '%d' % max_iter])
         if ll_delta:
@@ -1499,12 +1566,15 @@ class TadmMaxentClassifier(MaxentClassifier):
         # Build the classifier
         return cls(encoding, weights)
 
+
 ######################################################################
-#{ Demo
+# { Demo
 ######################################################################
 def demo():
     from nltk.classify.util import names_demo
+
     classifier = names_demo(MaxentClassifier.train)
 
+
 if __name__ == '__main__':
     demo()
