@@ -1,6 +1,6 @@
 # CHILDES XML Corpus Reader
 
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2019 NLTK Project
 # Author: Tomonori Nagano <tnagano@gc.cuny.edu>
 #         Alexis Dimitriadis <A.Dimitriadis@uu.nl>
 # URL: <http://nltk.org/>
@@ -25,6 +25,7 @@ from nltk.corpus.reader.xmldocs import XMLCorpusReader, ElementTree
 # to resolve the namespace issue
 NS = 'http://www.talkbank.org/ns/talkbank'
 
+
 class CHILDESCorpusReader(XMLCorpusReader):
     """
     Corpus reader for the XML version of the CHILDES corpus.
@@ -36,12 +37,20 @@ class CHILDESCorpusReader(XMLCorpusReader):
     For access to the file text use the usual nltk functions,
     ``words()``, ``sents()``, ``tagged_words()`` and ``tagged_sents()``.
     """
+
     def __init__(self, root, fileids, lazy=True):
         XMLCorpusReader.__init__(self, root, fileids)
         self._lazy = lazy
 
-    def words(self, fileids=None, speaker='ALL', stem=False,
-            relation=False, strip_space=True, replace=False):
+    def words(
+        self,
+        fileids=None,
+        speaker='ALL',
+        stem=False,
+        relation=False,
+        strip_space=True,
+        replace=False,
+    ):
         """
         :return: the given file(s) as a list of words
         :rtype: list(str)
@@ -58,18 +67,30 @@ class CHILDESCorpusReader(XMLCorpusReader):
         :param replace: If true, then use the replaced (intended) word instead
             of the original word (e.g., 'wat' will be replaced with 'watch')
         """
-        sent=None
-        pos=False
+        sent = None
+        pos = False
         if not self._lazy:
-            return [self._get_words(fileid, speaker, sent, stem, relation,
-                pos, strip_space, replace) for fileid in self.abspaths(fileids)]
+            return [
+                self._get_words(
+                    fileid, speaker, sent, stem, relation, pos, strip_space, replace
+                )
+                for fileid in self.abspaths(fileids)
+            ]
 
-        get_words = lambda fileid: self._get_words(fileid, speaker, sent, stem, relation,
-            pos, strip_space, replace)
+        get_words = lambda fileid: self._get_words(
+            fileid, speaker, sent, stem, relation, pos, strip_space, replace
+        )
         return LazyConcatenation(LazyMap(get_words, self.abspaths(fileids)))
 
-    def tagged_words(self, fileids=None, speaker='ALL', stem=False,
-            relation=False, strip_space=True, replace=False):
+    def tagged_words(
+        self,
+        fileids=None,
+        speaker='ALL',
+        stem=False,
+        relation=False,
+        strip_space=True,
+        replace=False,
+    ):
         """
         :return: the given file(s) as a list of tagged
             words and punctuation symbols, encoded as tuples
@@ -88,18 +109,30 @@ class CHILDESCorpusReader(XMLCorpusReader):
         :param replace: If true, then use the replaced (intended) word instead
             of the original word (e.g., 'wat' will be replaced with 'watch')
         """
-        sent=None
-        pos=True
+        sent = None
+        pos = True
         if not self._lazy:
-            return [self._get_words(fileid, speaker, sent, stem, relation,
-                pos, strip_space, replace) for fileid in self.abspaths(fileids)]
+            return [
+                self._get_words(
+                    fileid, speaker, sent, stem, relation, pos, strip_space, replace
+                )
+                for fileid in self.abspaths(fileids)
+            ]
 
-        get_words = lambda fileid: self._get_words(fileid, speaker, sent, stem, relation,
-            pos, strip_space, replace)
+        get_words = lambda fileid: self._get_words(
+            fileid, speaker, sent, stem, relation, pos, strip_space, replace
+        )
         return LazyConcatenation(LazyMap(get_words, self.abspaths(fileids)))
 
-    def sents(self, fileids=None, speaker='ALL', stem=False,
-            relation=None, strip_space=True, replace=False):
+    def sents(
+        self,
+        fileids=None,
+        speaker='ALL',
+        stem=False,
+        relation=None,
+        strip_space=True,
+        replace=False,
+    ):
         """
         :return: the given file(s) as a list of sentences or utterances, each
             encoded as a list of word strings.
@@ -118,18 +151,30 @@ class CHILDESCorpusReader(XMLCorpusReader):
         :param replace: If true, then use the replaced (intended) word instead
             of the original word (e.g., 'wat' will be replaced with 'watch')
         """
-        sent=True
-        pos=False
+        sent = True
+        pos = False
         if not self._lazy:
-            return [self._get_words(fileid, speaker, sent, stem, relation,
-                pos, strip_space, replace) for fileid in self.abspaths(fileids)]
+            return [
+                self._get_words(
+                    fileid, speaker, sent, stem, relation, pos, strip_space, replace
+                )
+                for fileid in self.abspaths(fileids)
+            ]
 
-        get_words = lambda fileid: self._get_words(fileid, speaker, sent, stem, relation,
-            pos, strip_space, replace)
+        get_words = lambda fileid: self._get_words(
+            fileid, speaker, sent, stem, relation, pos, strip_space, replace
+        )
         return LazyConcatenation(LazyMap(get_words, self.abspaths(fileids)))
 
-    def tagged_sents(self, fileids=None, speaker='ALL', stem=False,
-            relation=None, strip_space=True, replace=False):
+    def tagged_sents(
+        self,
+        fileids=None,
+        speaker='ALL',
+        stem=False,
+        relation=None,
+        strip_space=True,
+        replace=False,
+    ):
         """
         :return: the given file(s) as a list of
             sentences, each encoded as a list of ``(word,tag)`` tuples.
@@ -148,14 +193,19 @@ class CHILDESCorpusReader(XMLCorpusReader):
         :param replace: If true, then use the replaced (intended) word instead
             of the original word (e.g., 'wat' will be replaced with 'watch')
         """
-        sent=True
-        pos=True
+        sent = True
+        pos = True
         if not self._lazy:
-            return [self._get_words(fileid, speaker, sent, stem, relation,
-                pos, strip_space, replace) for fileid in self.abspaths(fileids)]
+            return [
+                self._get_words(
+                    fileid, speaker, sent, stem, relation, pos, strip_space, replace
+                )
+                for fileid in self.abspaths(fileids)
+            ]
 
-        get_words = lambda fileid: self._get_words(fileid, speaker, sent, stem, relation,
-            pos, strip_space, replace)
+        get_words = lambda fileid: self._get_words(
+            fileid, speaker, sent, stem, relation, pos, strip_space, replace
+        )
         return LazyConcatenation(LazyMap(get_words, self.abspaths(fileids)))
 
     def corpus(self, fileids=None):
@@ -192,9 +242,10 @@ class CHILDESCorpusReader(XMLCorpusReader):
         xmldoc = ElementTree.parse(fileid).getroot()
         # getting participants' data
         pat = dictOfDicts()
-        for participant in xmldoc.findall('.//{%s}Participants/{%s}participant'
-                                          % (NS,NS)):
-            for (key,value) in participant.items():
+        for participant in xmldoc.findall(
+            './/{%s}Participants/{%s}participant' % (NS, NS)
+        ):
+            for (key, value) in participant.items():
                 pat[participant.get('id')][key] = value
         return pat
 
@@ -206,15 +257,16 @@ class CHILDESCorpusReader(XMLCorpusReader):
         :param month: If true, return months instead of year-month-date
         """
         if not self._lazy:
-            return [self._get_age(fileid, speaker, month)
-                for fileid in self.abspaths(fileids)]
+            return [
+                self._get_age(fileid, speaker, month)
+                for fileid in self.abspaths(fileids)
+            ]
         get_age = lambda fileid: self._get_age(fileid, speaker, month)
         return LazyMap(get_age, self.abspaths(fileids))
 
     def _get_age(self, fileid, speaker, month):
         xmldoc = ElementTree.parse(fileid).getroot()
-        for pat in xmldoc.findall('.//{%s}Participants/{%s}participant'
-                                  % (NS,NS)):
+        for pat in xmldoc.findall('.//{%s}Participants/{%s}participant' % (NS, NS)):
             try:
                 if pat.get('id') == speaker:
                     age = pat.get('age')
@@ -227,8 +279,8 @@ class CHILDESCorpusReader(XMLCorpusReader):
 
     def convert_age(self, age_year):
         "Caclculate age in months from a string in CHILDES format"
-        m = re.match("P(\d+)Y(\d+)M?(\d?\d?)D?",age_year)
-        age_month = int(m.group(1))*12 + int(m.group(2))
+        m = re.match("P(\d+)Y(\d+)M?(\d?\d?)D?", age_year)
+        age_month = int(m.group(1)) * 12 + int(m.group(2))
         try:
             if int(m.group(3)) > 15:
                 age_month += 1
@@ -243,33 +295,43 @@ class CHILDESCorpusReader(XMLCorpusReader):
         :rtype: list(float)
         """
         if not self._lazy:
-            return [self._getMLU(fileid, speaker=speaker)
-                for fileid in self.abspaths(fileids)]
+            return [
+                self._getMLU(fileid, speaker=speaker)
+                for fileid in self.abspaths(fileids)
+            ]
         get_MLU = lambda fileid: self._getMLU(fileid, speaker=speaker)
         return LazyMap(get_MLU, self.abspaths(fileids))
 
     def _getMLU(self, fileid, speaker):
-        sents = self._get_words(fileid, speaker=speaker, sent=True, stem=True,
-                    relation=False, pos=True, strip_space=True, replace=True)
+        sents = self._get_words(
+            fileid,
+            speaker=speaker,
+            sent=True,
+            stem=True,
+            relation=False,
+            pos=True,
+            strip_space=True,
+            replace=True,
+        )
         results = []
         lastSent = []
         numFillers = 0
         sentDiscount = 0
         for sent in sents:
-            posList = [pos for (word,pos) in sent]
+            posList = [pos for (word, pos) in sent]
             # if any part of the sentence is intelligible
             if any(pos == 'unk' for pos in posList):
-                next
+                continue
             # if the sentence is null
             elif sent == []:
-                next
+                continue
             # if the sentence is the same as the last sent
             elif sent == lastSent:
-                next
+                continue
             else:
-                results.append([word for (word,pos) in sent])
+                results.append([word for (word, pos) in sent])
                 # count number of fillers
-                if len(set(['co',None]).intersection(posList)) > 0:
+                if len(set(['co', None]).intersection(posList)) > 0:
                     numFillers += posList.count('co')
                     numFillers += posList.count(None)
                     sentDiscount += 1
@@ -278,19 +340,23 @@ class CHILDESCorpusReader(XMLCorpusReader):
             thisWordList = flatten(results)
             # count number of morphemes
             # (e.g., 'read' = 1 morpheme but 'read-PAST' is 2 morphemes)
-            numWords = len(flatten([word.split('-')
-                                          for word in thisWordList])) - numFillers
+            numWords = (
+                len(flatten([word.split('-') for word in thisWordList])) - numFillers
+            )
             numSents = len(results) - sentDiscount
-            mlu = numWords/numSents
+            mlu = numWords / numSents
         except ZeroDivisionError:
             mlu = 0
         # return {'mlu':mlu,'wordNum':numWords,'sentNum':numSents}
         return mlu
 
-    def _get_words(self, fileid, speaker, sent, stem, relation, pos,
-            strip_space, replace):
-        if isinstance(speaker, string_types) and speaker != 'ALL':  # ensure we have a list of speakers
-            speaker = [ speaker ]
+    def _get_words(
+        self, fileid, speaker, sent, stem, relation, pos, strip_space, replace
+    ):
+        if (
+            isinstance(speaker, string_types) and speaker != 'ALL'
+        ):  # ensure we have a list of speakers
+            speaker = [speaker]
         xmldoc = ElementTree.parse(fileid).getroot()
         # processing each xml doc
         results = []
@@ -299,14 +365,16 @@ class CHILDESCorpusReader(XMLCorpusReader):
             # select speakers
             if speaker == 'ALL' or xmlsent.get('who') in speaker:
                 for xmlword in xmlsent.findall('.//{%s}w' % NS):
-                    infl = None ; suffixStem = None; suffixTag = None
+                    infl = None
+                    suffixStem = None
+                    suffixTag = None
                     # getting replaced words
-                    if replace and xmlsent.find('.//{%s}w/{%s}replacement'
-                                                % (NS,NS)):
-                        xmlword = xmlsent.find('.//{%s}w/{%s}replacement/{%s}w'
-                                               % (NS,NS,NS))
-                    elif replace and xmlsent.find('.//{%s}w/{%s}wk' % (NS,NS)):
-                        xmlword = xmlsent.find('.//{%s}w/{%s}wk' % (NS,NS))
+                    if replace and xmlsent.find('.//{%s}w/{%s}replacement' % (NS, NS)):
+                        xmlword = xmlsent.find(
+                            './/{%s}w/{%s}replacement/{%s}w' % (NS, NS, NS)
+                        )
+                    elif replace and xmlsent.find('.//{%s}w/{%s}wk' % (NS, NS)):
+                        xmlword = xmlsent.find('.//{%s}w/{%s}wk' % (NS, NS))
                     # get text
                     if xmlword.text:
                         word = xmlword.text
@@ -324,78 +392,111 @@ class CHILDESCorpusReader(XMLCorpusReader):
                             pass
                         # if there is an inflection
                         try:
-                            xmlinfl = xmlword.find('.//{%s}mor/{%s}mw/{%s}mk'
-                                                   % (NS,NS,NS))
+                            xmlinfl = xmlword.find(
+                                './/{%s}mor/{%s}mw/{%s}mk' % (NS, NS, NS)
+                            )
                             word += '-' + xmlinfl.text
                         except:
                             pass
                         # if there is a suffix
                         try:
-                            xmlsuffix = xmlword.find('.//{%s}mor/{%s}mor-post/{%s}mw/{%s}stem'
-                                                     % (NS,NS,NS,NS))
+                            xmlsuffix = xmlword.find(
+                                './/{%s}mor/{%s}mor-post/{%s}mw/{%s}stem'
+                                % (NS, NS, NS, NS)
+                            )
                             suffixStem = xmlsuffix.text
                         except AttributeError:
                             suffixStem = ""
                         if suffixStem:
-                            word += "~"+suffixStem
+                            word += "~" + suffixStem
                     # pos
                     if relation or pos:
                         try:
                             xmlpos = xmlword.findall(".//{%s}c" % NS)
                             xmlpos2 = xmlword.findall(".//{%s}s" % NS)
                             if xmlpos2 != []:
-                                tag = xmlpos[0].text+":"+xmlpos2[0].text
+                                tag = xmlpos[0].text + ":" + xmlpos2[0].text
                             else:
                                 tag = xmlpos[0].text
-                        except (AttributeError,IndexError) as e:
+                        except (AttributeError, IndexError) as e:
                             tag = ""
                         try:
-                            xmlsuffixpos = xmlword.findall('.//{%s}mor/{%s}mor-post/{%s}mw/{%s}pos/{%s}c'
-                                                     % (NS,NS,NS,NS,NS))
-                            xmlsuffixpos2 = xmlword.findall('.//{%s}mor/{%s}mor-post/{%s}mw/{%s}pos/{%s}s'
-                                                     % (NS,NS,NS,NS,NS))
+                            xmlsuffixpos = xmlword.findall(
+                                './/{%s}mor/{%s}mor-post/{%s}mw/{%s}pos/{%s}c'
+                                % (NS, NS, NS, NS, NS)
+                            )
+                            xmlsuffixpos2 = xmlword.findall(
+                                './/{%s}mor/{%s}mor-post/{%s}mw/{%s}pos/{%s}s'
+                                % (NS, NS, NS, NS, NS)
+                            )
                             if xmlsuffixpos2:
-                                suffixTag = xmlsuffixpos[0].text+":"+xmlsuffixpos2[0].text
+                                suffixTag = (
+                                    xmlsuffixpos[0].text + ":" + xmlsuffixpos2[0].text
+                                )
                             else:
                                 suffixTag = xmlsuffixpos[0].text
                         except:
                             pass
                         if suffixTag:
-                            tag += "~"+suffixTag
+                            tag += "~" + suffixTag
                         word = (word, tag)
                     # relational
                     # the gold standard is stored in
                     # <mor></mor><mor type="trn"><gra type="grt">
                     if relation == True:
-                        for xmlstem_rel in xmlword.findall('.//{%s}mor/{%s}gra'
-                                                           % (NS,NS)):
+                        for xmlstem_rel in xmlword.findall(
+                            './/{%s}mor/{%s}gra' % (NS, NS)
+                        ):
                             if not xmlstem_rel.get('type') == 'grt':
-                                word = (word[0], word[1],
-                                        xmlstem_rel.get('index')
-                                        + "|" + xmlstem_rel.get('head')
-                                        + "|" + xmlstem_rel.get('relation'))
+                                word = (
+                                    word[0],
+                                    word[1],
+                                    xmlstem_rel.get('index')
+                                    + "|"
+                                    + xmlstem_rel.get('head')
+                                    + "|"
+                                    + xmlstem_rel.get('relation'),
+                                )
                             else:
-                                word = (word[0], word[1], word[2],
-                                        word[0], word[1],
-                                        xmlstem_rel.get('index')
-                                        + "|" + xmlstem_rel.get('head')
-                                        + "|" + xmlstem_rel.get('relation'))
+                                word = (
+                                    word[0],
+                                    word[1],
+                                    word[2],
+                                    word[0],
+                                    word[1],
+                                    xmlstem_rel.get('index')
+                                    + "|"
+                                    + xmlstem_rel.get('head')
+                                    + "|"
+                                    + xmlstem_rel.get('relation'),
+                                )
                         try:
-                            for xmlpost_rel in xmlword.findall('.//{%s}mor/{%s}mor-post/{%s}gra'
-                                                               % (NS,NS,NS)):
+                            for xmlpost_rel in xmlword.findall(
+                                './/{%s}mor/{%s}mor-post/{%s}gra' % (NS, NS, NS)
+                            ):
                                 if not xmlpost_rel.get('type') == 'grt':
-                                    suffixStem = (suffixStem[0],
-                                                  suffixStem[1],
-                                                  xmlpost_rel.get('index')
-                                                  + "|" + xmlpost_rel.get('head')
-                                                  + "|" + xmlpost_rel.get('relation'))
+                                    suffixStem = (
+                                        suffixStem[0],
+                                        suffixStem[1],
+                                        xmlpost_rel.get('index')
+                                        + "|"
+                                        + xmlpost_rel.get('head')
+                                        + "|"
+                                        + xmlpost_rel.get('relation'),
+                                    )
                                 else:
-                                    suffixStem = (suffixStem[0], suffixStem[1],
-                                                  suffixStem[2], suffixStem[0],
-                                                  suffixStem[1],
-                                                  xmlpost_rel.get('index')
-                                                  + "|" + xmlpost_rel.get('head')
-                                                  + "|" + xmlpost_rel.get('relation'))
+                                    suffixStem = (
+                                        suffixStem[0],
+                                        suffixStem[1],
+                                        suffixStem[2],
+                                        suffixStem[0],
+                                        suffixStem[1],
+                                        xmlpost_rel.get('index')
+                                        + "|"
+                                        + xmlpost_rel.get('head')
+                                        + "|"
+                                        + xmlpost_rel.get('relation'),
+                                    )
                         except:
                             pass
                     sents.append(word)
@@ -405,7 +506,6 @@ class CHILDESCorpusReader(XMLCorpusReader):
                     results.extend(sents)
         return LazyMap(lambda x: x, results)
 
-
     # Ready-to-use browser opener
 
     """
@@ -415,7 +515,6 @@ class CHILDESCorpusReader(XMLCorpusReader):
     """
     childes_url_base = r'http://childes.psy.cmu.edu/browser/index.php?url='
 
-
     def webview_file(self, fileid, urlbase=None):
         """Map a corpus file to its web version on the CHILDES website,
         and open it in a web browser.
@@ -440,7 +539,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
         import webbrowser, re
 
         if urlbase:
-            path = urlbase+"/"+fileid
+            path = urlbase + "/" + fileid
         else:
             full = self.root + "/" + fileid
             full = re.sub(r'\\', '/', full)
@@ -457,7 +556,7 @@ class CHILDESCorpusReader(XMLCorpusReader):
             path = path[:-4]
 
         if not path.endswith('.cha'):
-            path = path+'.cha'
+            path = path + '.cha'
 
         url = self.childes_url_base + path
 
@@ -467,7 +566,6 @@ class CHILDESCorpusReader(XMLCorpusReader):
         # raw_input("Hit Return to continue")
 
 
-
 def demo(corpus_root=None):
     """
     The CHILDES corpus should be manually downloaded and saved
@@ -475,6 +573,7 @@ def demo(corpus_root=None):
     """
     if not corpus_root:
         from nltk.data import find
+
         corpus_root = find('corpora/childes/data-xml/Eng-USA/')
 
     try:
@@ -483,21 +582,31 @@ def demo(corpus_root=None):
         for file in childes.fileids()[:5]:
             corpus = ''
             corpus_id = ''
-            for (key,value) in childes.corpus(file)[0].items():
-                if key == "Corpus": corpus = value
-                if key == "Id": corpus_id = value
-            print('Reading', corpus,corpus_id,' .....')
-            print("words:", childes.words(file)[:7],"...")
-            print("words with replaced words:", childes.words(file, replace=True)[:7]," ...")
-            print("words with pos tags:", childes.tagged_words(file)[:7]," ...")
+            for (key, value) in childes.corpus(file)[0].items():
+                if key == "Corpus":
+                    corpus = value
+                if key == "Id":
+                    corpus_id = value
+            print('Reading', corpus, corpus_id, ' .....')
+            print("words:", childes.words(file)[:7], "...")
+            print(
+                "words with replaced words:",
+                childes.words(file, replace=True)[:7],
+                " ...",
+            )
+            print("words with pos tags:", childes.tagged_words(file)[:7], " ...")
             print("words (only MOT):", childes.words(file, speaker='MOT')[:7], "...")
             print("words (only CHI):", childes.words(file, speaker='CHI')[:7], "...")
-            print("stemmed words:", childes.words(file, stem=True)[:7]," ...")
-            print("words with relations and pos-tag:", childes.words(file, relation=True)[:5]," ...")
-            print("sentence:", childes.sents(file)[:2]," ...")
+            print("stemmed words:", childes.words(file, stem=True)[:7], " ...")
+            print(
+                "words with relations and pos-tag:",
+                childes.words(file, relation=True)[:5],
+                " ...",
+            )
+            print("sentence:", childes.sents(file)[:2], " ...")
             for (participant, values) in childes.participants(file)[0].items():
-                    for (key, value) in values.items():
-                        print("\tparticipant", participant, key, ":", value)
+                for (key, value) in values.items():
+                    print("\tparticipant", participant, key, ":", value)
             print("num of sent:", len(childes.sents(file)))
             print("num of morphemes:", len(childes.words(file, stem=True)))
             print("age:", childes.age(file))
@@ -506,16 +615,18 @@ def demo(corpus_root=None):
             print()
 
     except LookupError as e:
-        print("""The CHILDES corpus, or the parts you need, should be manually
+        print(
+            """The CHILDES corpus, or the parts you need, should be manually
         downloaded from http://childes.psy.cmu.edu/data-xml/ and saved at
         [NLTK_Data_Dir]/corpora/childes/
             Alternately, you can call the demo with the path to a portion of the CHILDES corpus, e.g.:
         demo('/path/to/childes/data-xml/Eng-USA/")
-        """)
-        #corpus_root_http = urllib2.urlopen('http://childes.psy.cmu.edu/data-xml/Eng-USA/Bates.zip')
-        #corpus_root_http_bates = zipfile.ZipFile(cStringIO.StringIO(corpus_root_http.read()))
+        """
+        )
+        # corpus_root_http = urllib2.urlopen('http://childes.psy.cmu.edu/data-xml/Eng-USA/Bates.zip')
+        # corpus_root_http_bates = zipfile.ZipFile(cStringIO.StringIO(corpus_root_http.read()))
         ##this fails
-        #childes = CHILDESCorpusReader(corpus_root_http_bates,corpus_root_http_bates.namelist())
+        # childes = CHILDESCorpusReader(corpus_root_http_bates,corpus_root_http_bates.namelist())
 
 
 if __name__ == "__main__":
