@@ -1,6 +1,6 @@
 # Natural Language Toolkit: Table widget
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2019 NLTK Project
 # Author: Edward Loper <edloper@gmail.com>
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
@@ -14,13 +14,14 @@ from __future__ import division
 
 import operator
 
-from six.moves.tkinter import (Frame, Label, Listbox, Scrollbar, Tk)
+from six.moves.tkinter import Frame, Label, Listbox, Scrollbar, Tk
 
 
 ######################################################################
 # Multi-Column Listbox
 ######################################################################
 
+
 class MultiListbox(Frame):
     """
     A multi-column listbox, where the current selection applies to an
@@ -31,32 +32,37 @@ class MultiListbox(Frame):
     contained listboxes.  For any methods that do not have docstrings,
     see ``Tkinter.Listbox`` for a description of what that method does.
     """
-    #/////////////////////////////////////////////////////////////////
+
+    # /////////////////////////////////////////////////////////////////
     # Configuration
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     #: Default configuration values for the frame.
-    FRAME_CONFIG = dict(background='#888',
-                        takefocus=True,
-                        highlightthickness=1)
+    FRAME_CONFIG = dict(background='#888', takefocus=True, highlightthickness=1)
 
     #: Default configurations for the column labels.
-    LABEL_CONFIG = dict(borderwidth=1, relief='raised',
-                        font='helvetica -16 bold',
-                      background='#444', foreground='white')
+    LABEL_CONFIG = dict(
+        borderwidth=1,
+        relief='raised',
+        font='helvetica -16 bold',
+        background='#444',
+        foreground='white',
+    )
 
     #: Default configuration for the column listboxes.
-    LISTBOX_CONFIG = dict(borderwidth=1,
-                          selectborderwidth=0,
-                          highlightthickness=0,
-                          exportselection=False,
-                          selectbackground='#888',
-                          activestyle='none',
-                          takefocus=False)
+    LISTBOX_CONFIG = dict(
+        borderwidth=1,
+        selectborderwidth=0,
+        highlightthickness=0,
+        exportselection=False,
+        selectbackground='#888',
+        activestyle='none',
+        takefocus=False,
+    )
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Constructor
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def __init__(self, master, columns, column_weights=None, cnf={}, **kw):
         """
@@ -148,9 +154,9 @@ class MultiListbox(Frame):
         # Configuration customizations
         self.configure(cnf, **kw)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Column Resizing
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def _resize_column(self, event):
         """
@@ -168,18 +174,19 @@ class MultiListbox(Frame):
         self._resize_column_index = None
         if event.widget is self:
             for i, lb in enumerate(self._listboxes):
-                if abs(event.x-(lb.winfo_x()+lb.winfo_width())) < 10:
+                if abs(event.x - (lb.winfo_x() + lb.winfo_width())) < 10:
                     self._resize_column_index = i
-        elif event.x > (event.widget.winfo_width()-5):
+        elif event.x > (event.widget.winfo_width() - 5):
             self._resize_column_index = event.widget.column_index
         elif event.x < 5 and event.widget.column_index != 0:
-            self._resize_column_index = event.widget.column_index-1
+            self._resize_column_index = event.widget.column_index - 1
 
         # Bind callbacks that are used to resize it.
         if self._resize_column_index is not None:
             event.widget.bind('<Motion>', self._resize_column_motion_cb)
-            event.widget.bind('<ButtonRelease-%d>' % event.num,
-                              self._resize_column_buttonrelease_cb)
+            event.widget.bind(
+                '<ButtonRelease-%d>' % event.num, self._resize_column_buttonrelease_cb
+            )
             return True
         else:
             return False
@@ -191,15 +198,15 @@ class MultiListbox(Frame):
         x1 = event.x + event.widget.winfo_x()
         x2 = lb.winfo_x() + lb.winfo_width()
 
-        lb['width'] = max(3, lb['width'] + (x1-x2) // charwidth)
+        lb['width'] = max(3, lb['width'] + (x1 - x2) // charwidth)
 
     def _resize_column_buttonrelease_cb(self, event):
         event.widget.unbind('<ButtonRelease-%d>' % event.num)
         event.widget.unbind('<Motion>')
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Properties
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     @property
     def column_names(self):
@@ -233,9 +240,9 @@ class MultiListbox(Frame):
         """
         return tuple(self._listboxes)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Mouse & Keyboard Callback Functions
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def _select(self, e):
         i = e.widget.nearest(e.y)
@@ -253,9 +260,9 @@ class MultiListbox(Frame):
         """:return: The number of rows that makes up one page"""
         return int(self.index('@0,1000000')) - int(self.index('@0,0'))
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Row selection
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def select(self, index=None, delta=None, see=True):
         """
@@ -283,14 +290,15 @@ class MultiListbox(Frame):
 
         # Select the specified index
         if index is not None:
-            index = min(max(index, 0), self.size()-1)
-            #self.activate(index)
+            index = min(max(index, 0), self.size() - 1)
+            # self.activate(index)
             self.selection_set(index)
-            if see: self.see(index)
+            if see:
+                self.see(index)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Configuration
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def configure(self, cnf={}, **kw):
         """
@@ -310,14 +318,14 @@ class MultiListbox(Frame):
                 for listbox in self._listboxes:
                     listbox.configure({key[8:]: val})
             else:
-                Frame.configure(self, {key:val})
+                Frame.configure(self, {key: val})
 
     def __setitem__(self, key, val):
         """
         Configure this widget.  This is equivalent to
         ``self.configure({key,val``)}.  See ``configure()``.
         """
-        self.configure({key:val})
+        self.configure({key: val})
 
     def rowconfigure(self, row_index, cnf={}, **kw):
         """
@@ -325,7 +333,8 @@ class MultiListbox(Frame):
         arguments are: ``background``, ``bg``, ``foreground``, ``fg``,
         ``selectbackground``, ``selectforeground``.
         """
-        for lb in self._listboxes: lb.itemconfigure(row_index, cnf, **kw)
+        for lb in self._listboxes:
+            lb.itemconfigure(row_index, cnf, **kw)
 
     def columnconfigure(self, col_index, cnf={}, **kw):
         """
@@ -337,11 +346,18 @@ class MultiListbox(Frame):
 
         cnf = dict(list(cnf.items()) + list(kw.items()))
         for (key, val) in list(cnf.items()):
-            if key in ('background', 'bg', 'foreground', 'fg',
-                       'selectbackground', 'selectforeground'):
-                for i in range(lb.size()): lb.itemconfigure(i, {key:val})
+            if key in (
+                'background',
+                'bg',
+                'foreground',
+                'fg',
+                'selectbackground',
+                'selectforeground',
+            ):
+                for i in range(lb.size()):
+                    lb.itemconfigure(i, {key: val})
             else:
-                lb.configure({key:val})
+                lb.configure({key: val})
 
     def itemconfigure(self, row_index, col_index, cnf=None, **kw):
         """
@@ -352,9 +368,9 @@ class MultiListbox(Frame):
         lb = self._listboxes[col_index]
         return lb.itemconfigure(row_index, cnf, **kw)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Value Access
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def insert(self, index, *rows):
         """
@@ -366,9 +382,11 @@ class MultiListbox(Frame):
         """
         for elt in rows:
             if len(elt) != len(self._column_names):
-                raise ValueError('rows should be tuples whose length '
-                                 'is equal to the number of columns')
-        for (lb,elts) in zip(self._listboxes, list(zip(*rows))):
+                raise ValueError(
+                    'rows should be tuples whose length '
+                    'is equal to the number of columns'
+                )
+        for (lb, elts) in zip(self._listboxes, list(zip(*rows))):
             lb.insert(index, *elts)
 
     def get(self, first, last=None):
@@ -392,11 +410,11 @@ class MultiListbox(Frame):
         """
         dx, dy, _, _ = self.grid_bbox(row=0, column=col)
         x, y, w, h = self._listboxes[col].bbox(row)
-        return int(x)+int(dx), int(y)+int(dy), int(w), int(h)
+        return int(x) + int(dx), int(y) + int(dy), int(w), int(h)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Hide/Show Columns
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def hide_column(self, col_index):
         """
@@ -419,15 +437,17 @@ class MultiListbox(Frame):
         """
         weight = self._column_weights[col_index]
         if self._labels:
-            self._labels[col_index].grid(column=col_index, row=0,
-                                         sticky='news', padx=0, pady=0)
-        self._listboxes[col_index].grid(column=col_index, row=1,
-                                        sticky='news', padx=0, pady=0)
+            self._labels[col_index].grid(
+                column=col_index, row=0, sticky='news', padx=0, pady=0
+            )
+        self._listboxes[col_index].grid(
+            column=col_index, row=1, sticky='news', padx=0, pady=0
+        )
         self.grid_columnconfigure(col_index, weight=weight)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Binding Methods
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def bind_to_labels(self, sequence=None, func=None, add=None):
         """
@@ -439,8 +459,7 @@ class MultiListbox(Frame):
             functions (if any), allowing for their deletion (to
             prevent a memory leak).
         """
-        return [label.bind(sequence, func, add)
-                for label in self.column_labels]
+        return [label.bind(sequence, func, add) for label in self.column_labels]
 
     def bind_to_listboxes(self, sequence=None, func=None, add=None):
         """
@@ -465,55 +484,82 @@ class MultiListbox(Frame):
             functions (if any), allowing for their deletion (to
             prevent a memory leak).
         """
-        return (self.bind_to_labels(sequence, func, add) +
-                self.bind_to_listboxes(sequence, func, add))
+        return self.bind_to_labels(sequence, func, add) + self.bind_to_listboxes(
+            sequence, func, add
+        )
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Simple Delegation
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     # These methods delegate to the first listbox:
     def curselection(self, *args, **kwargs):
         return self._listboxes[0].curselection(*args, **kwargs)
+
     def selection_includes(self, *args, **kwargs):
         return self._listboxes[0].selection_includes(*args, **kwargs)
+
     def itemcget(self, *args, **kwargs):
         return self._listboxes[0].itemcget(*args, **kwargs)
+
     def size(self, *args, **kwargs):
         return self._listboxes[0].size(*args, **kwargs)
+
     def index(self, *args, **kwargs):
         return self._listboxes[0].index(*args, **kwargs)
+
     def nearest(self, *args, **kwargs):
         return self._listboxes[0].nearest(*args, **kwargs)
 
     # These methods delegate to each listbox (and return None):
     def activate(self, *args, **kwargs):
-        for lb in self._listboxes: lb.activate(*args, **kwargs)
-    def delete(self, *args, **kwargs):
-        for lb in self._listboxes: lb.delete(*args, **kwargs)
-    def scan_mark(self, *args, **kwargs):
-        for lb in self._listboxes: lb.scan_mark(*args, **kwargs)
-    def scan_dragto(self, *args, **kwargs):
-        for lb in self._listboxes: lb.scan_dragto(*args, **kwargs)
-    def see(self, *args, **kwargs):
-        for lb in self._listboxes: lb.see(*args, **kwargs)
-    def selection_anchor(self, *args, **kwargs):
-        for lb in self._listboxes: lb.selection_anchor(*args, **kwargs)
-    def selection_clear(self, *args, **kwargs):
-        for lb in self._listboxes: lb.selection_clear(*args, **kwargs)
-    def selection_set(self, *args, **kwargs):
-        for lb in self._listboxes: lb.selection_set(*args, **kwargs)
-    def yview(self, *args, **kwargs):
-        for lb in self._listboxes: v = lb.yview(*args, **kwargs)
-        return v # if called with no arguments
-    def yview_moveto(self, *args, **kwargs):
-        for lb in self._listboxes: lb.yview_moveto(*args, **kwargs)
-    def yview_scroll(self, *args, **kwargs):
-        for lb in self._listboxes: lb.yview_scroll(*args, **kwargs)
+        for lb in self._listboxes:
+            lb.activate(*args, **kwargs)
 
-    #/////////////////////////////////////////////////////////////////
+    def delete(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.delete(*args, **kwargs)
+
+    def scan_mark(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.scan_mark(*args, **kwargs)
+
+    def scan_dragto(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.scan_dragto(*args, **kwargs)
+
+    def see(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.see(*args, **kwargs)
+
+    def selection_anchor(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.selection_anchor(*args, **kwargs)
+
+    def selection_clear(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.selection_clear(*args, **kwargs)
+
+    def selection_set(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.selection_set(*args, **kwargs)
+
+    def yview(self, *args, **kwargs):
+        for lb in self._listboxes:
+            v = lb.yview(*args, **kwargs)
+        return v  # if called with no arguments
+
+    def yview_moveto(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.yview_moveto(*args, **kwargs)
+
+    def yview_scroll(self, *args, **kwargs):
+        for lb in self._listboxes:
+            lb.yview_scroll(*args, **kwargs)
+
+    # /////////////////////////////////////////////////////////////////
     # Aliases
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     itemconfig = itemconfigure
     rowconfig = rowconfigure
@@ -523,17 +569,19 @@ class MultiListbox(Frame):
     select_includes = selection_includes
     select_set = selection_set
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # These listbox methods are not defined for multi-listbox
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # def xview(self, *what): pass
     # def xview_moveto(self, fraction): pass
     # def xview_scroll(self, number, what): pass
 
+
 ######################################################################
 # Table
 ######################################################################
 
+
 class Table(object):
     """
     A display widget for a table of values, based on a ``MultiListbox``
@@ -572,10 +620,19 @@ class Table(object):
         table.  Each element of _rows is a row value, i.e., a list of
         cell values, one for each column in the row.
     """
-    def __init__(self, master, column_names, rows=None,
-                 column_weights=None,
-                 scrollbar=True, click_to_sort=True,
-                 reprfunc=None, cnf={}, **kw):
+
+    def __init__(
+        self,
+        master,
+        column_names,
+        rows=None,
+        column_weights=None,
+        scrollbar=True,
+        click_to_sort=True,
+        reprfunc=None,
+        cnf={},
+        **kw
+    ):
         """
         Construct a new Table widget.
 
@@ -611,25 +668,25 @@ class Table(object):
         self._reprfunc = reprfunc
         self._frame = Frame(master)
 
-        self._column_name_to_index = dict((c,i) for (i,c) in
-                                          enumerate(column_names))
+        self._column_name_to_index = dict((c, i) for (i, c) in enumerate(column_names))
 
         # Make a copy of the rows & check that it's valid.
-        if rows is None: self._rows = []
-        else: self._rows = [[v for v in row] for row in rows]
-        for row in self._rows: self._checkrow(row)
+        if rows is None:
+            self._rows = []
+        else:
+            self._rows = [[v for v in row] for row in rows]
+        for row in self._rows:
+            self._checkrow(row)
 
         # Create our multi-list box.
-        self._mlb = MultiListbox(self._frame, column_names,
-                                 column_weights, cnf, **kw)
+        self._mlb = MultiListbox(self._frame, column_names, column_weights, cnf, **kw)
         self._mlb.pack(side='left', expand=True, fill='both')
 
         # Optional scrollbar
         if scrollbar:
-            sb = Scrollbar(self._frame, orient='vertical',
-                           command=self._mlb.yview)
+            sb = Scrollbar(self._frame, orient='vertical', command=self._mlb.yview)
             self._mlb.listboxes[0]['yscrollcommand'] = sb.set
-            #for listbox in self._mlb.listboxes:
+            # for listbox in self._mlb.listboxes:
             #    listbox['yscrollcommand'] = sb.set
             sb.pack(side='right', fill='y')
             self._scrollbar = sb
@@ -643,9 +700,9 @@ class Table(object):
         # Fill in our multi-list box.
         self._fill_table()
 
-    #/////////////////////////////////////////////////////////////////
-    #{ Widget-like Methods
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
+    # { Widget-like Methods
+    # /////////////////////////////////////////////////////////////////
     # These all just delegate to either our frame or our MLB.
 
     def pack(self, *args, **kwargs):
@@ -697,9 +754,9 @@ class Table(object):
     columnconfig = columnconfigure
     itemconfig = itemconfigure
 
-    #/////////////////////////////////////////////////////////////////
-    #{ Table as list-of-lists
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
+    # { Table as list-of-lists
+    # /////////////////////////////////////////////////////////////////
 
     def insert(self, row_index, rowvalue):
         """
@@ -714,10 +771,12 @@ class Table(object):
         self._checkrow(rowvalue)
         self._rows.insert(row_index, rowvalue)
         if self._reprfunc is not None:
-            rowvalue = [self._reprfunc(row_index,j,v)
-                        for (j,v) in enumerate(rowvalue)]
+            rowvalue = [
+                self._reprfunc(row_index, j, v) for (j, v) in enumerate(rowvalue)
+            ]
         self._mlb.insert(row_index, rowvalue)
-        if self._DEBUG: self._check_table_vs_mlb()
+        if self._DEBUG:
+            self._check_table_vs_mlb()
 
     def extend(self, rowvalues):
         """
@@ -727,8 +786,10 @@ class Table(object):
             table.  Each row value should be a tuple of cell values,
             one for each column in the row.
         """
-        for rowvalue in rowvalues: self.append(rowvalue)
-        if self._DEBUG: self._check_table_vs_mlb()
+        for rowvalue in rowvalues:
+            self.append(rowvalue)
+        if self._DEBUG:
+            self._check_table_vs_mlb()
 
     def append(self, rowvalue):
         """
@@ -738,7 +799,8 @@ class Table(object):
             in the new row.
         """
         self.insert(len(self._rows), rowvalue)
-        if self._DEBUG: self._check_table_vs_mlb()
+        if self._DEBUG:
+            self._check_table_vs_mlb()
 
     def clear(self):
         """
@@ -746,7 +808,8 @@ class Table(object):
         """
         self._rows = []
         self._mlb.delete(0, 'end')
-        if self._DEBUG: self._check_table_vs_mlb()
+        if self._DEBUG:
+            self._check_table_vs_mlb()
 
     def __getitem__(self, index):
         """
@@ -759,7 +822,7 @@ class Table(object):
         """
         if isinstance(index, slice):
             raise ValueError('Slicing not supported')
-        elif isinstance(index, tuple) and len(index)==2:
+        elif isinstance(index, tuple) and len(index) == 2:
             return self._rows[index[0]][self.column_index(index[1])]
         else:
             return tuple(self._rows[index])
@@ -781,16 +844,15 @@ class Table(object):
         if isinstance(index, slice):
             raise ValueError('Slicing not supported')
 
-
         # table[i,j] = val
-        elif isinstance(index, tuple) and len(index)==2:
+        elif isinstance(index, tuple) and len(index) == 2:
             i, j = index[0], self.column_index(index[1])
             config_cookie = self._save_config_info([i])
             self._rows[i][j] = val
             if self._reprfunc is not None:
                 val = self._reprfunc(i, j, val)
             self._mlb.listboxes[j].insert(i, val)
-            self._mlb.listboxes[j].delete(i+1)
+            self._mlb.listboxes[j].delete(i + 1)
             self._restore_config_info(config_cookie)
 
         # table[i] = val
@@ -799,9 +861,9 @@ class Table(object):
             self._checkrow(val)
             self._rows[index] = list(val)
             if self._reprfunc is not None:
-                val = [self._reprfunc(index,j,v) for (j,v) in enumerate(val)]
+                val = [self._reprfunc(index, j, v) for (j, v) in enumerate(val)]
             self._mlb.insert(index, val)
-            self._mlb.delete(index+1)
+            self._mlb.delete(index + 1)
             self._restore_config_info(config_cookie)
 
     def __delitem__(self, row_index):
@@ -810,11 +872,12 @@ class Table(object):
         """
         if isinstance(row_index, slice):
             raise ValueError('Slicing not supported')
-        if isinstance(row_index, tuple) and len(row_index)==2:
+        if isinstance(row_index, tuple) and len(row_index) == 2:
             raise ValueError('Cannot delete a single cell!')
         del self._rows[row_index]
         self._mlb.delete(row_index)
-        if self._DEBUG: self._check_table_vs_mlb()
+        if self._DEBUG:
+            self._check_table_vs_mlb()
 
     def __len__(self):
         """
@@ -828,12 +891,14 @@ class Table(object):
         number of elements; and if not, raise an exception.
         """
         if len(rowvalue) != self._num_columns:
-            raise ValueError('Row %r has %d columns; expected %d' %
-                             (rowvalue, len(rowvalue), self._num_columns))
+            raise ValueError(
+                'Row %r has %d columns; expected %d'
+                % (rowvalue, len(rowvalue), self._num_columns)
+            )
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Columns
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     @property
     def column_names(self):
@@ -861,9 +926,9 @@ class Table(object):
         """:see: ``MultiListbox.show_column()``"""
         self._mlb.show_column(self.column_index(column_index))
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Selection
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def selected_row(self):
         """
@@ -872,16 +937,18 @@ class Table(object):
         ``table[table.selected_row()]``.
         """
         sel = self._mlb.curselection()
-        if sel: return int(sel[0])
-        else: return None
+        if sel:
+            return int(sel[0])
+        else:
+            return None
 
     def select(self, index=None, delta=None, see=True):
         """:see: ``MultiListbox.select()``"""
         self._mlb.select(index, delta, see)
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Sorting
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     def sort_by(self, column_index, order='toggle'):
         """
@@ -903,8 +970,9 @@ class Table(object):
                 order.
         """
         if order not in ('ascending', 'descending', 'toggle'):
-            raise ValueError('sort_by(): order should be "ascending", '
-                             '"descending", or "toggle".')
+            raise ValueError(
+                'sort_by(): order should be "ascending", ' '"descending", or "toggle".'
+            )
         column_index = self.column_index(column_index)
         config_cookie = self._save_config_info(index_by_id=True)
 
@@ -912,14 +980,16 @@ class Table(object):
         if order == 'toggle' and column_index == self._sortkey:
             self._rows.reverse()
         else:
-            self._rows.sort(key=operator.itemgetter(column_index),
-                            reverse=(order=='descending'))
+            self._rows.sort(
+                key=operator.itemgetter(column_index), reverse=(order == 'descending')
+            )
             self._sortkey = column_index
 
         # Redraw the table.
         self._fill_table()
         self._restore_config_info(config_cookie, index_by_id=True, see=True)
-        if self._DEBUG: self._check_table_vs_mlb()
+        if self._DEBUG:
+            self._check_table_vs_mlb()
 
     def _sort(self, event):
         """Event handler for clicking on a column label -- sort by
@@ -936,9 +1006,9 @@ class Table(object):
             self.sort_by(column_index)
             return 'continue'
 
-    #/////////////////////////////////////////////////////////////////
-    #{ Table Drawing Helpers
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
+    # { Table Drawing Helpers
+    # /////////////////////////////////////////////////////////////////
 
     def _fill_table(self, save_config=True):
         """
@@ -952,13 +1022,19 @@ class Table(object):
         self._mlb.delete(0, 'end')
         for i, row in enumerate(self._rows):
             if self._reprfunc is not None:
-                row = [self._reprfunc(i,j,v) for (j,v) in enumerate(row)]
+                row = [self._reprfunc(i, j, v) for (j, v) in enumerate(row)]
             self._mlb.insert('end', row)
 
     def _get_itemconfig(self, r, c):
-        return dict( (k, self._mlb.itemconfig(r, c, k)[-1])
-                     for k in ('foreground', 'selectforeground',
-                               'background', 'selectbackground') )
+        return dict(
+            (k, self._mlb.itemconfig(r, c, k)[-1])
+            for k in (
+                'foreground',
+                'selectforeground',
+                'background',
+                'selectbackground',
+            )
+        )
 
     def _save_config_info(self, row_indices=None, index_by_id=False):
         """
@@ -986,14 +1062,18 @@ class Table(object):
 
         # Look up the color configuration info for each row.
         if index_by_id:
-            config = dict((id(self._rows[r]), [self._get_itemconfig(r, c)
-                                        for c in range(self._num_columns)])
-                          for r in row_indices)
+            config = dict(
+                (
+                    id(self._rows[r]),
+                    [self._get_itemconfig(r, c) for c in range(self._num_columns)],
+                )
+                for r in row_indices
+            )
         else:
-            config = dict((r, [self._get_itemconfig(r, c)
-                               for c in range(self._num_columns)])
-                          for r in row_indices)
-
+            config = dict(
+                (r, [self._get_itemconfig(r, c) for c in range(self._num_columns)])
+                for r in row_indices
+            )
 
         return selection, config
 
@@ -1023,9 +1103,9 @@ class Table(object):
                 for c in range(self._num_columns):
                     self._mlb.itemconfigure(r, c, config[r][c])
 
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
     # Debugging (Invariant Checker)
-    #/////////////////////////////////////////////////////////////////
+    # /////////////////////////////////////////////////////////////////
 
     _DEBUG = False
     """If true, then run ``_check_table_vs_mlb()`` after any operation
@@ -1043,13 +1123,14 @@ class Table(object):
         for row in self:
             assert len(row) == self._num_columns
         assert self._num_columns == len(self._mlb.column_names)
-        #assert self._column_names == self._mlb.column_names
+        # assert self._column_names == self._mlb.column_names
         for i, row in enumerate(self):
             for j, cell in enumerate(row):
                 if self._reprfunc is not None:
                     cell = self._reprfunc(i, j, cell)
                 assert self._mlb.get(i)[j] == cell
 
+
 ######################################################################
 # Demo/Test Function
 ######################################################################
@@ -1059,15 +1140,20 @@ def demo():
     root = Tk()
     root.bind('<Control-q>', lambda e: root.destroy())
 
-    table = Table(root, 'Word Synset Hypernym Hyponym'.split(),
-                  column_weights=[0, 1, 1, 1],
-                  reprfunc=(lambda i,j,s: '  %s' % s))
+    table = Table(
+        root,
+        'Word Synset Hypernym Hyponym'.split(),
+        column_weights=[0, 1, 1, 1],
+        reprfunc=(lambda i, j, s: '  %s' % s),
+    )
     table.pack(expand=True, fill='both')
 
     from nltk.corpus import wordnet
     from nltk.corpus import brown
+
     for word, pos in sorted(set(brown.tagged_words()[:500])):
-        if pos[0] != 'N': continue
+        if pos[0] != 'N':
+            continue
         word = word.lower()
         for synset in wordnet.synsets(word):
             try:
@@ -1078,10 +1164,7 @@ def demo():
                 hypo_def = synset.hypernyms()[0].definition()
             except:
                 hypo_def = '*none*'
-            table.append([word,
-                          synset.definition(),
-                          hyper_def,
-                          hypo_def])
+            table.append([word, synset.definition(), hyper_def, hypo_def])
 
     table.columnconfig('Word', background='#afa')
     table.columnconfig('Synset', background='#efe')
@@ -1090,9 +1173,11 @@ def demo():
     for row in range(len(table)):
         for column in ('Hypernym', 'Hyponym'):
             if table[row, column] == '*none*':
-                table.itemconfig(row, column, foreground='#666',
-                                 selectforeground='#666')
+                table.itemconfig(
+                    row, column, foreground='#666', selectforeground='#666'
+                )
     root.mainloop()
 
+
 if __name__ == '__main__':
     demo()
