@@ -4,20 +4,20 @@
 # Author: Dan Garrette <dhgarrette@gmail.com>
 # Contributor: Liling Tan, Mustufain, osamamukhtar11
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2019 NLTK Project
 # URL: <http://nltk.org/>
 # For license information, see LICENSE.TXT
 
-from __future__ import print_function
-from __future__ import unicode_literals
+from __future__ import print_function, unicode_literals
 
-from six import text_type
 import os
 import sys
 import tempfile
 import subprocess
 import inspect
 
+from six import text_type
+
 from nltk.data import ZipFilePathPointer
 from nltk.internals import find_dir, find_file, find_jars_within_path
 
@@ -28,32 +28,39 @@ from nltk.parse.util import taggedsents_to_conll
 
 def malt_regex_tagger():
     from nltk.tag import RegexpTagger
+
     _tagger = RegexpTagger(
-    [(r'\.$','.'), (r'\,$',','), (r'\?$','?'),    # fullstop, comma, Qmark
-    (r'\($','('), (r'\)$',')'),             # round brackets
-    (r'\[$','['), (r'\]$',']'),             # square brackets
-    (r'^-?[0-9]+(.[0-9]+)?$', 'CD'),        # cardinal numbers
-    (r'(The|the|A|a|An|an)$', 'DT'),        # articles
-    (r'(He|he|She|she|It|it|I|me|Me|You|you)$', 'PRP'), # pronouns
-    (r'(His|his|Her|her|Its|its)$', 'PRP$'),    # possesive
-    (r'(my|Your|your|Yours|yours)$', 'PRP$'),   # possesive
-    (r'(on|On|in|In|at|At|since|Since)$', 'IN'),# time prepopsitions
-    (r'(for|For|ago|Ago|before|Before)$', 'IN'),# time prepopsitions
-    (r'(till|Till|until|Until)$', 'IN'),        # time prepopsitions
-    (r'(by|By|beside|Beside)$', 'IN'),          # space prepopsitions
-    (r'(under|Under|below|Below)$', 'IN'),      # space prepopsitions
-    (r'(over|Over|above|Above)$', 'IN'),        # space prepopsitions
-    (r'(across|Across|through|Through)$', 'IN'),# space prepopsitions
-    (r'(into|Into|towards|Towards)$', 'IN'),    # space prepopsitions
-    (r'(onto|Onto|from|From)$', 'IN'),          # space prepopsitions
-    (r'.*able$', 'JJ'), # adjectives
-    (r'.*ness$', 'NN'), # nouns formed from adjectives
-    (r'.*ly$', 'RB'),   # adverbs
-    (r'.*s$', 'NNS'),   # plural nouns
-    (r'.*ing$', 'VBG'), # gerunds
-    (r'.*ed$', 'VBD'),  # past tense verbs
-    (r'.*', 'NN'),      # nouns (default)
-    ])
+        [
+            (r'\.$', '.'),
+            (r'\,$', ','),
+            (r'\?$', '?'),  # fullstop, comma, Qmark
+            (r'\($', '('),
+            (r'\)$', ')'),  # round brackets
+            (r'\[$', '['),
+            (r'\]$', ']'),  # square brackets
+            (r'^-?[0-9]+(.[0-9]+)?$', 'CD'),  # cardinal numbers
+            (r'(The|the|A|a|An|an)$', 'DT'),  # articles
+            (r'(He|he|She|she|It|it|I|me|Me|You|you)$', 'PRP'),  # pronouns
+            (r'(His|his|Her|her|Its|its)$', 'PRP$'),  # possesive
+            (r'(my|Your|your|Yours|yours)$', 'PRP$'),  # possesive
+            (r'(on|On|in|In|at|At|since|Since)$', 'IN'),  # time prepopsitions
+            (r'(for|For|ago|Ago|before|Before)$', 'IN'),  # time prepopsitions
+            (r'(till|Till|until|Until)$', 'IN'),  # time prepopsitions
+            (r'(by|By|beside|Beside)$', 'IN'),  # space prepopsitions
+            (r'(under|Under|below|Below)$', 'IN'),  # space prepopsitions
+            (r'(over|Over|above|Above)$', 'IN'),  # space prepopsitions
+            (r'(across|Across|through|Through)$', 'IN'),  # space prepopsitions
+            (r'(into|Into|towards|Towards)$', 'IN'),  # space prepopsitions
+            (r'(onto|Onto|from|From)$', 'IN'),  # space prepopsitions
+            (r'.*able$', 'JJ'),  # adjectives
+            (r'.*ness$', 'NN'),  # nouns formed from adjectives
+            (r'.*ly$', 'RB'),  # adverbs
+            (r'.*s$', 'NNS'),  # plural nouns
+            (r'.*ing$', 'VBG'),  # gerunds
+            (r'.*ed$', 'VBD'),  # past tense verbs
+            (r'.*', 'NN'),  # nouns (default)
+        ]
+    )
     return _tagger.tag
 
 
@@ -61,18 +68,20 @@ def find_maltparser(parser_dirname):
     """
     A module to find MaltParser .jar file and its dependencies.
     """
-    if os.path.exists(parser_dirname): # If a full path is given.
+    if os.path.exists(parser_dirname):  # If a full path is given.
         _malt_dir = parser_dirname
-    else: # Try to find path to maltparser directory in environment variables.
+    else:  # Try to find path to maltparser directory in environment variables.
         _malt_dir = find_dir(parser_dirname, env_vars=('MALT_PARSER',))
     # Checks that that the found directory contains all the necessary .jar
-    malt_dependencies = ['','','']
+    malt_dependencies = ['', '', '']
     _malt_jars = set(find_jars_within_path(_malt_dir))
     _jars = set(os.path.split(jar)[1] for jar in _malt_jars)
     malt_dependencies = set(['log4j.jar', 'libsvm.jar', 'liblinear-1.8.jar'])
 
     assert malt_dependencies.issubset(_jars)
-    assert any(filter(lambda i: i.startswith('maltparser-') and i.endswith('.jar'), _jars))
+    assert any(
+        filter(lambda i: i.startswith('maltparser-') and i.endswith('.jar'), _jars)
+    )
     return list(_malt_jars)
 
 
@@ -80,11 +89,11 @@ def find_malt_model(model_filename):
     """
     A module to find pre-trained MaltParser model.
     """
-    if model_filename == None:
+    if model_filename is None:
         return 'malt_temp.mco'
-    elif os.path.exists(model_filename): # If a full path is given.
+    elif os.path.exists(model_filename):  # If a full path is given.
         return model_filename
-    else: # Try to find path to malt model in environment variables.
+    else:  # Try to find path to malt model in environment variables.
         return find_file(model_filename, env_vars=('MALT_MODEL',), verbose=False)
 
 
@@ -107,7 +116,14 @@ class MaltParser(ParserI):
         >>> mp.parse_one('I shot an elephant in my pajamas .'.split()).tree() # doctest: +SKIP
         (shot I (elephant an) (in (pajamas my)) .)
     """
-    def __init__(self, parser_dirname, model_filename=None, tagger=None, additional_java_args=None):
+
+    def __init__(
+        self,
+        parser_dirname,
+        model_filename=None,
+        tagger=None,
+        additional_java_args=None,
+    ):
         """
         An interface for parsing with the Malt Parser.
 
@@ -132,8 +148,9 @@ class MaltParser(ParserI):
         # Find all the necessary jar files for MaltParser.
         self.malt_jars = find_maltparser(parser_dirname)
         # Initialize additional java arguments.
-        self.additional_java_args = additional_java_args if \
-                        additional_java_args is not None else []
+        self.additional_java_args = (
+            additional_java_args if additional_java_args is not None else []
+        )
         # Initialize model.
         self.model = find_malt_model(model_filename)
         self._trained = self.model != 'malt_temp.mco'
@@ -156,38 +173,54 @@ class MaltParser(ParserI):
         if not self._trained:
             raise Exception("Parser has not been trained. Call train() first.")
 
-        with tempfile.NamedTemporaryFile(prefix='malt_input.conll.',
-              dir=self.working_dir, mode='w', delete=False) as input_file:
-              with tempfile.NamedTemporaryFile(prefix='malt_output.conll.',
-                     dir=self.working_dir, mode='w', delete=False) as output_file:
+        with tempfile.NamedTemporaryFile(
+            prefix='malt_input.conll.', dir=self.working_dir, mode='w', delete=False
+        ) as input_file:
+            with tempfile.NamedTemporaryFile(
+                prefix='malt_output.conll.',
+                dir=self.working_dir,
+                mode='w',
+                delete=False,
+            ) as output_file:
                 # Convert list of sentences to CONLL format.
                 for line in taggedsents_to_conll(sentences):
                     input_file.write(text_type(line))
                 input_file.close()
 
                 # Generate command to run maltparser.
-                cmd =self.generate_malt_command(input_file.name,
-                                output_file.name, mode="parse")
+                cmd = self.generate_malt_command(
+                    input_file.name, output_file.name, mode="parse"
+                )
 
                 # This is a maltparser quirk, it needs to be run
                 # where the model file is. otherwise it goes into an awkward
                 # missing .jars or strange -w working_dir problem.
-                _current_path = os.getcwd() # Remembers the current path.
-                try: # Change to modelfile path
+                _current_path = os.getcwd()  # Remembers the current path.
+                try:  # Change to modelfile path
                     os.chdir(os.path.split(self.model)[0])
                 except:
                     pass
-                ret = self._execute(cmd, verbose) # Run command.
-                os.chdir(_current_path) # Change back to current path.
+                ret = self._execute(cmd, verbose)  # Run command.
+                os.chdir(_current_path)  # Change back to current path.
 
                 if ret is not 0:
-                    raise Exception("MaltParser parsing (%s) failed with exit "
-                            "code %d" % (' '.join(cmd), ret))
+                    raise Exception(
+                        "MaltParser parsing (%s) failed with exit "
+                        "code %d" % (' '.join(cmd), ret)
+                    )
 
                 # Must return iter(iter(Tree))
                 with open(output_file.name) as infile:
                     for tree_str in infile.read().split('\n\n'):
-                        yield(iter([DependencyGraph(tree_str, top_relation_label=top_relation_label)]))
+                        yield (
+                            iter(
+                                [
+                                    DependencyGraph(
+                                        tree_str, top_relation_label=top_relation_label
+                                    )
+                                ]
+                            )
+                        )
 
         os.remove(input_file.name)
         os.remove(output_file.name)
@@ -204,7 +237,9 @@ class MaltParser(ParserI):
         :return: iter(DependencyGraph)
         """
         tagged_sentences = (self.tagger(sentence) for sentence in sentences)
-        return self.parse_tagged_sents(tagged_sentences, verbose, top_relation_label=top_relation_label)
+        return self.parse_tagged_sents(
+            tagged_sentences, verbose, top_relation_label=top_relation_label
+        )
 
     def generate_malt_command(self, inputfilename, outputfilename=None, mode=None):
         """
@@ -217,22 +252,25 @@ class MaltParser(ParserI):
         """
 
         cmd = ['java']
-        cmd+= self.additional_java_args # Adds additional java arguments
+        cmd += self.additional_java_args  # Adds additional java arguments
         # Joins classpaths with ";" if on Windows and on Linux/Mac use ":"
         classpaths_separator = ';' if sys.platform.startswith('win') else ':'
-        cmd+= ['-cp', classpaths_separator.join(self.malt_jars)] # Adds classpaths for jars
-        cmd+= ['org.maltparser.Malt'] # Adds the main function.
+        cmd += [
+            '-cp',
+            classpaths_separator.join(self.malt_jars),
+        ]  # Adds classpaths for jars
+        cmd += ['org.maltparser.Malt']  # Adds the main function.
 
         # Adds the model file.
-        if os.path.exists(self.model): # when parsing
-            cmd+= ['-c', os.path.split(self.model)[-1]]
-        else: # when learning
-            cmd+= ['-c', self.model]
+        if os.path.exists(self.model):  # when parsing
+            cmd += ['-c', os.path.split(self.model)[-1]]
+        else:  # when learning
+            cmd += ['-c', self.model]
 
-        cmd+= ['-i', inputfilename]
+        cmd += ['-i', inputfilename]
         if mode == 'parse':
-            cmd+= ['-o', outputfilename]
-        cmd+= ['-m', mode] # mode use to generate parses.
+            cmd += ['-o', outputfilename]
+        cmd += ['-m', mode]  # mode use to generate parses.
         return cmd
 
     @staticmethod
@@ -250,9 +288,10 @@ class MaltParser(ParserI):
         """
 
         # Write the conll_str to malt_train.conll file in /tmp/
-        with tempfile.NamedTemporaryFile(prefix='malt_train.conll.',
-             dir=self.working_dir, mode='w', delete=False) as input_file:
-            input_str = ('\n'.join(dg.to_conll(10) for dg in depgraphs))
+        with tempfile.NamedTemporaryFile(
+            prefix='malt_train.conll.', dir=self.working_dir, mode='w', delete=False
+        ) as input_file:
+            input_str = '\n'.join(dg.to_conll(10) for dg in depgraphs)
             input_file.write(text_type(input_str))
         # Trains the model with the malt_train.conll
         self.train_from_file(input_file.name, verbose=verbose)
@@ -269,19 +308,22 @@ class MaltParser(ParserI):
         # If conll_file is a ZipFilePathPointer,
         # then we need to do some extra massaging
         if isinstance(conll_file, ZipFilePathPointer):
-            with tempfile.NamedTemporaryFile(prefix='malt_train.conll.',
-            dir=self.working_dir, mode='w', delete=False) as input_file:
+            with tempfile.NamedTemporaryFile(
+                prefix='malt_train.conll.', dir=self.working_dir, mode='w', delete=False
+            ) as input_file:
                 with conll_file.open() as conll_input_file:
                     conll_str = conll_input_file.read()
                     input_file.write(text_type(conll_str))
                 return self.train_from_file(input_file.name, verbose=verbose)
 
         # Generate command to run maltparser.
-        cmd =self.generate_malt_command(conll_file, mode="learn")
+        cmd = self.generate_malt_command(conll_file, mode="learn")
         ret = self._execute(cmd, verbose)
         if ret != 0:
-            raise Exception("MaltParser training (%s) failed with exit "
-                    "code %d" % (' '.join(cmd), ret))
+            raise Exception(
+                "MaltParser training (%s) failed with exit "
+                "code %d" % (' '.join(cmd), ret)
+            )
         self._trained = True
 
 
@@ -353,4 +395,5 @@ if __name__ == '__main__':
     (flies Time (like banana) .)
     '''
     import doctest
+
     doctest.testmod()
