@@ -1,6 +1,6 @@
 # Natural Language Toolkit: TnT Tagger
 #
-# Copyright (C) 2001-2018 NLTK Project
+# Copyright (C) 2001-2019 NLTK Project
 # Author: Sam Huston <sjh900@gmail.com>
 #
 # URL: <http://nltk.org/>
@@ -20,6 +20,7 @@ from operator import itemgetter
 from nltk.probability import FreqDist, ConditionalFreqDist
 from nltk.tag.api import TaggerI
 
+
 class TnT(TaggerI):
     '''
     TnT - Statistical POS tagger
@@ -112,17 +113,17 @@ class TnT(TaggerI):
         of the tagger
         '''
 
-        self._uni  = FreqDist()
-        self._bi   = ConditionalFreqDist()
-        self._tri  = ConditionalFreqDist()
-        self._wd   = ConditionalFreqDist()
-        self._eos  = ConditionalFreqDist()
-        self._l1   = 0.0
-        self._l2   = 0.0
-        self._l3   = 0.0
-        self._N    = N
-        self._C    = C
-        self._T    = Trained
+        self._uni = FreqDist()
+        self._bi = ConditionalFreqDist()
+        self._tri = ConditionalFreqDist()
+        self._wd = ConditionalFreqDist()
+        self._eos = ConditionalFreqDist()
+        self._l1 = 0.0
+        self._l2 = 0.0
+        self._l3 = 0.0
+        self._N = N
+        self._C = C
+        self._T = Trained
 
         self._unk = unk
 
@@ -147,20 +148,21 @@ class TnT(TaggerI):
             self._unk.train(data)
 
         for sent in data:
-            history = [('BOS',False), ('BOS',False)]
+            history = [('BOS', False), ('BOS', False)]
             for w, t in sent:
 
                 # if capitalization is requested,
                 # and the word begins with a capital
                 # set local flag C to True
-                if self._C and w[0].isupper(): C=True
+                if self._C and w[0].isupper():
+                    C = True
 
                 self._wd[w][t] += 1
-                self._uni[(t,C)] += 1
-                self._bi[history[1]][(t,C)] += 1
-                self._tri[tuple(history)][(t,C)] += 1
+                self._uni[(t, C)] += 1
+                self._bi[history[1]][(t, C)] += 1
+                self._tri[tuple(history)][(t, C)] += 1
 
-                history.append((t,C))
+                history.append((t, C))
                 history.pop(0)
 
                 # set local flag C to false for the next word
@@ -168,14 +170,12 @@ class TnT(TaggerI):
 
             self._eos[t]['EOS'] += 1
 
-
         # compute lambda values from the trained frequency distributions
         self._compute_lambda()
 
-        #(debugging -- ignore or delete me)
-        #print "lambdas"
-        #print i, self._l1, i, self._l2, i, self._l3
-
+        # (debugging -- ignore or delete me)
+        # print "lambdas"
+        # print i, self._l1, i, self._l2, i, self._l3
 
     def _compute_lambda(self):
         '''
@@ -218,10 +218,11 @@ class TnT(TaggerI):
 
                 # safe_div provides a safe floating point division
                 # it returns -1 if the denominator is 0
-                c3 = self._safe_div((self._tri[history][tag]-1), (self._tri[history].N()-1))
-                c2 = self._safe_div((self._bi[h2][tag]-1), (self._bi[h2].N()-1))
-                c1 = self._safe_div((self._uni[tag]-1), (self._uni.N()-1))
-
+                c3 = self._safe_div(
+                    (self._tri[history][tag] - 1), (self._tri[history].N() - 1)
+                )
+                c2 = self._safe_div((self._bi[h2][tag] - 1), (self._bi[h2].N() - 1))
+                c1 = self._safe_div((self._uni[tag] - 1), (self._uni.N() - 1))
 
                 # if c1 is the maximum value:
                 if (c1 > c3) and (c1 > c2):
@@ -249,16 +250,14 @@ class TnT(TaggerI):
                 # otherwise there might be a problem
                 # eg: all values = 0
                 else:
-                    #print "Problem", c1, c2 ,c3
+                    # print "Problem", c1, c2 ,c3
                     pass
 
         # Lambda normalisation:
         # ensures that l1+l2+l3 = 1
-        self._l1 = tl1 / (tl1+tl2+tl3)
-        self._l2 = tl2 / (tl1+tl2+tl3)
-        self._l3 = tl3 / (tl1+tl2+tl3)
-
-
+        self._l1 = tl1 / (tl1 + tl2 + tl3)
+        self._l2 = tl2 / (tl1 + tl2 + tl3)
+        self._l3 = tl3 / (tl1 + tl2 + tl3)
 
     def _safe_div(self, v1, v2):
         '''
@@ -288,7 +287,6 @@ class TnT(TaggerI):
             res.append(res1)
         return res
 
-
     def tag(self, data):
         '''
         Tags a single sentence
@@ -316,12 +314,11 @@ class TnT(TaggerI):
         res = []
         for i in range(len(sent)):
             # unpack and discard the C flags
-            (t,C) = tags[i+2]
+            (t, C) = tags[i + 2]
             res.append((sent[i], t))
 
         return res
 
-
     def _tagword(self, sent, current_states):
         '''
         :param sent : List of words remaining in the sentence
@@ -352,7 +349,8 @@ class TnT(TaggerI):
         # if the Capitalisation is requested,
         # initalise the flag for this word
         C = False
-        if self._C and word[0].isupper(): C=True
+        if self._C and word[0].isupper():
+            C = True
 
         # if word is known
         # compute the set of possible tags
@@ -364,17 +362,16 @@ class TnT(TaggerI):
                 logprobs = []
 
                 for t in self._wd[word].keys():
-                    tC = (t,C)
+                    tC = (t, C)
                     p_uni = self._uni.freq(tC)
                     p_bi = self._bi[history[-1]].freq(tC)
                     p_tri = self._tri[tuple(history[-2:])].freq(tC)
                     p_wd = self._wd[word][t] / self._uni[tC]
-                    p = self._l1 *p_uni + self._l2 *p_bi + self._l3 *p_tri
+                    p = self._l1 * p_uni + self._l2 * p_bi + self._l3 * p_tri
                     p2 = log(p, 2) + log(p_wd, 2)
 
                     # compute the result of appending each tag to this history
-                    new_states.append((history + [tC],
-                                       curr_sent_logprob + p2))
+                    new_states.append((history + [tC], curr_sent_logprob + p2))
 
         # otherwise a new word, set of possible tags is unknown
         else:
@@ -389,12 +386,12 @@ class TnT(TaggerI):
             # if no unknown word tagger has been specified
             # then use the tag 'Unk'
             if self._unk is None:
-                tag = ('Unk',C)
+                tag = ('Unk', C)
 
             # otherwise apply the unknown word tagger
             else:
                 [(_w, t)] = list(self._unk.tag([word]))
-                tag = (t,C)
+                tag = (t, C)
 
             for (history, logprob) in current_states:
                 history.append(tag)
@@ -410,7 +407,7 @@ class TnT(TaggerI):
         # del everything after N (threshold)
         # this is the beam search cut
         if len(new_states) > self._N:
-            new_states = new_states[:self._N]
+            new_states = new_states[: self._N]
 
         # compute the tags for the rest of the sentence
         # return the best list of tags for the sentence
@@ -421,6 +418,7 @@ class TnT(TaggerI):
 # helper function -- basic sentence tokenizer
 ########################################
 
+
 def basic_sent_chop(data, raw=True):
     '''
     Basic method for tokenizing input into sentences
@@ -448,8 +446,7 @@ def basic_sent_chop(data, raw=True):
 
     new_data = []
     curr_sent = []
-    sent_mark = [',','.','?','!']
-
+    sent_mark = [',', '.', '?', '!']
 
     if raw:
         for word in data:
@@ -461,19 +458,19 @@ def basic_sent_chop(data, raw=True):
                 curr_sent.append(word)
 
     else:
-        for (word,tag) in data:
+        for (word, tag) in data:
             if word in sent_mark:
-                curr_sent.append((word,tag))
+                curr_sent.append((word, tag))
                 new_data.append(curr_sent)
                 curr_sent = []
             else:
-                curr_sent.append((word,tag))
+                curr_sent.append((word, tag))
     return new_data
 
 
-
 def demo():
     from nltk.corpus import brown
+
     sents = list(brown.tagged_sents())
     test = list(brown.sents())
 
@@ -487,9 +484,9 @@ def demo():
     # print results
     for j in range(len(tagged_data)):
         s = tagged_data[j]
-        t = sents[j+100]
+        t = sents[j + 100]
         for i in range(len(s)):
-            print(s[i],'--', t[i])
+            print(s[i], '--', t[i])
         print()
 
 
@@ -500,11 +497,11 @@ def demo2():
 
     t = TnT(N=1000, C=False)
     s = TnT(N=1000, C=True)
-    t.train(d[(11)*100:])
-    s.train(d[(11)*100:])
+    t.train(d[(11) * 100 :])
+    s.train(d[(11) * 100 :])
 
     for i in range(10):
-        tacc = t.evaluate(d[i*100:((i+1)*100)])
+        tacc = t.evaluate(d[i * 100 : ((i + 1) * 100)])
         tp_un = t.unknown / (t.known + t.unknown)
         tp_kn = t.known / (t.known + t.unknown)
         t.unknown = 0
@@ -516,7 +513,7 @@ def demo2():
         print('Percentage unknown:', tp_un)
         print('Accuracy over known words:', (tacc / tp_kn))
 
-        sacc = s.evaluate(d[i*100:((i+1)*100)])
+        sacc = s.evaluate(d[i * 100 : ((i + 1) * 100)])
         sp_un = s.unknown / (s.known + s.unknown)
         sp_kn = s.known / (s.known + s.unknown)
         s.unknown = 0
@@ -528,6 +525,7 @@ def demo2():
         print('Percentage unknown:', sp_un)
         print('Accuracy over known words:', (sacc / sp_kn))
 
+
 def demo3():
     from nltk.corpus import treebank, brown
 
@@ -537,8 +535,8 @@ def demo3():
     d = d[:1000]
     e = e[:1000]
 
-    d10 = int(len(d)*0.1)
-    e10 = int(len(e)*0.1)
+    d10 = int(len(d) * 0.1)
+    e10 = int(len(e) * 0.1)
 
     tknacc = 0
     sknacc = 0
@@ -552,11 +550,11 @@ def demo3():
         t = TnT(N=1000, C=False)
         s = TnT(N=1000, C=False)
 
-        dtest = d[(i*d10):((i+1)*d10)]
-        etest = e[(i*e10):((i+1)*e10)]
+        dtest = d[(i * d10) : ((i + 1) * d10)]
+        etest = e[(i * e10) : ((i + 1) * e10)]
 
-        dtrain = d[:(i*d10)] + d[((i+1)*d10):]
-        etrain = e[:(i*e10)] + e[((i+1)*e10):]
+        dtrain = d[: (i * d10)] + d[((i + 1) * d10) :]
+        etrain = e[: (i * e10)] + e[((i + 1) * e10) :]
 
         t.train(dtrain)
         s.train(etrain)
@@ -575,13 +573,12 @@ def demo3():
         s.unknown = 0
         s.known = 0
 
-        tknacc += (tacc / tp_kn)
-        sknacc += (sacc / tp_kn)
+        tknacc += tacc / tp_kn
+        sknacc += sacc / tp_kn
         tallacc += tacc
         sallacc += sacc
 
-        #print i+1, (tacc / tp_kn), i+1, (sacc / tp_kn), i+1, tacc, i+1, sacc
-
+        # print i+1, (tacc / tp_kn), i+1, (sacc / tp_kn), i+1, tacc, i+1, sacc
 
     print("brown: acc over words known:", 10 * tknacc)
     print("     : overall accuracy:", 10 * tallacc)
@@ -589,7 +586,3 @@ def demo3():
     print("treebank: acc over words known:", 10 * sknacc)
     print("        : overall accuracy:", 10 * sallacc)
     print("        : words known:", 10 * sknown)
-
-
-
-
